/********************************************************************************
** Form generated from reading UI file 'profilewidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEWIDGETUI_H
#define UI_PROFILEWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProfileWidgetUI
{
public:
    QGridLayout *gridLayout;
    QListView *listView;
    QVBoxLayout *layout;
    QPushButton *kpushbutton_add;
    QPushButton *kpushbutton_rem;
    QPushButton *kpushbutton_mod;
    QPushButton *kpushbutton_copy;
    QSpacerItem *verticalSpacer;
    QPushButton *kpushbutton_init;
    QSpacerItem *spacerItem;
    QPushButton *kpushbutton_load;
    QPushButton *kpushbutton_save;

    void setupUi(QWidget *ProfileWidgetUI)
    {
        if (ProfileWidgetUI->objectName().isEmpty())
            ProfileWidgetUI->setObjectName("ProfileWidgetUI");
        ProfileWidgetUI->resize(520, 388);
        gridLayout = new QGridLayout(ProfileWidgetUI);
        gridLayout->setObjectName("gridLayout");
        listView = new QListView(ProfileWidgetUI);
        listView->setObjectName("listView");

        gridLayout->addWidget(listView, 0, 0, 1, 1);

        layout = new QVBoxLayout();
        layout->setObjectName("layout");
        kpushbutton_add = new QPushButton(ProfileWidgetUI);
        kpushbutton_add->setObjectName("kpushbutton_add");

        layout->addWidget(kpushbutton_add);

        kpushbutton_rem = new QPushButton(ProfileWidgetUI);
        kpushbutton_rem->setObjectName("kpushbutton_rem");

        layout->addWidget(kpushbutton_rem);

        kpushbutton_mod = new QPushButton(ProfileWidgetUI);
        kpushbutton_mod->setObjectName("kpushbutton_mod");

        layout->addWidget(kpushbutton_mod);

        kpushbutton_copy = new QPushButton(ProfileWidgetUI);
        kpushbutton_copy->setObjectName("kpushbutton_copy");

        layout->addWidget(kpushbutton_copy);

        verticalSpacer = new QSpacerItem(20, 32, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        layout->addItem(verticalSpacer);

        kpushbutton_init = new QPushButton(ProfileWidgetUI);
        kpushbutton_init->setObjectName("kpushbutton_init");

        layout->addWidget(kpushbutton_init);

        spacerItem = new QSpacerItem(93, 131, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        layout->addItem(spacerItem);

        kpushbutton_load = new QPushButton(ProfileWidgetUI);
        kpushbutton_load->setObjectName("kpushbutton_load");

        layout->addWidget(kpushbutton_load);

        kpushbutton_save = new QPushButton(ProfileWidgetUI);
        kpushbutton_save->setObjectName("kpushbutton_save");

        layout->addWidget(kpushbutton_save);


        gridLayout->addLayout(layout, 0, 1, 1, 1);


        retranslateUi(ProfileWidgetUI);

        QMetaObject::connectSlotsByName(ProfileWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *ProfileWidgetUI)
    {
        kpushbutton_add->setText(tr2i18n("Add...", nullptr));
        kpushbutton_rem->setText(tr2i18n("Remove", nullptr));
        kpushbutton_mod->setText(tr2i18n("Modify...", nullptr));
        kpushbutton_copy->setText(tr2i18n("Copy", nullptr));
        kpushbutton_init->setText(tr2i18n("Codec Scan", nullptr));
        kpushbutton_load->setText(tr2i18n("Load...", nullptr));
        kpushbutton_save->setText(tr2i18n("Save...", nullptr));
        (void)ProfileWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class ProfileWidgetUI: public Ui_ProfileWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEWIDGETUI_H

