/********************************************************************************
** Form generated from reading UI file 'devicewidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEVICEWIDGETUI_H
#define UI_DEVICEWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DeviceWidgetUI
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_fullParanoiaMode;
    QCheckBox *kcfg_skipReadErrors;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *kcfg_sampleShift;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_4;
    QSpinBox *kcfg_retriesOnReadError;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *DeviceWidgetUI)
    {
        if (DeviceWidgetUI->objectName().isEmpty())
            DeviceWidgetUI->setObjectName("DeviceWidgetUI");
        DeviceWidgetUI->resize(260, 190);
        gridLayout_2 = new QGridLayout(DeviceWidgetUI);
        gridLayout_2->setObjectName("gridLayout_2");
        groupBox_2 = new QGroupBox(DeviceWidgetUI);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName("gridLayout");
        kcfg_fullParanoiaMode = new QCheckBox(groupBox_2);
        kcfg_fullParanoiaMode->setObjectName("kcfg_fullParanoiaMode");

        gridLayout->addWidget(kcfg_fullParanoiaMode, 0, 0, 1, 1);

        kcfg_skipReadErrors = new QCheckBox(groupBox_2);
        kcfg_skipReadErrors->setObjectName("kcfg_skipReadErrors");

        gridLayout->addWidget(kcfg_skipReadErrors, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kcfg_sampleShift = new QSpinBox(groupBox_2);
        kcfg_sampleShift->setObjectName("kcfg_sampleShift");
        kcfg_sampleShift->setMinimumSize(QSize(0, 0));
        kcfg_sampleShift->setMaximumSize(QSize(16777215, 16777215));
        kcfg_sampleShift->setMinimum(-10000);
        kcfg_sampleShift->setMaximum(10000);

        horizontalLayout->addWidget(kcfg_sampleShift);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 4, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        horizontalLayout_4->addWidget(label_4);

        kcfg_retriesOnReadError = new QSpinBox(groupBox_2);
        kcfg_retriesOnReadError->setObjectName("kcfg_retriesOnReadError");
        kcfg_retriesOnReadError->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_retriesOnReadError->sizePolicy().hasHeightForWidth());
        kcfg_retriesOnReadError->setSizePolicy(sizePolicy1);
        kcfg_retriesOnReadError->setMaximumSize(QSize(16777215, 16777215));
        kcfg_retriesOnReadError->setBaseSize(QSize(0, 0));
        kcfg_retriesOnReadError->setMinimum(-10000);
        kcfg_retriesOnReadError->setMaximum(10000);
        kcfg_retriesOnReadError->setValue(20);

        horizontalLayout_4->addWidget(kcfg_retriesOnReadError);

        horizontalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);


        gridLayout->addLayout(horizontalLayout_4, 3, 0, 1, 1);


        gridLayout_2->addWidget(groupBox_2, 0, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 1, 0, 1, 1);


        retranslateUi(DeviceWidgetUI);

        QMetaObject::connectSlotsByName(DeviceWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *DeviceWidgetUI)
    {
        groupBox_2->setTitle(tr2i18n("Device", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_fullParanoiaMode->setToolTip(tr2i18n("<html><head/><body><p>Use some special techniques to reduce the chance of unnoticed reading errors. Leads to a more secure reading process at the expense of ripping speed, so it might be also called \"secure mode\".</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_fullParanoiaMode->setText(tr2i18n("Full paranoia mode (secure mode)", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_skipReadErrors->setToolTip(tr2i18n("<html><head/><body><p>Skip reading errors for a sector (sector length: 1/75 second) after retrying to read it. Please specify the number of retry attempts under <span style=\" font-style:italic;\">Retries on read error</span>. If skipped, null samples will be written for the faulty sectors.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_skipReadErrors->setText(tr2i18n("Skip read errors", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("<html><head/><body><p>Some drives have a sample offset when reading audio CDs. To determine the correct offset for your drive model, you can check the <a href=\"https://www.accuraterip.com/driveoffsets.htm\"><span style=\" text-decoration: underline; color:#2980b9;\">Accuraterip</span></a> database.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Sample shift:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_sampleShift->setToolTip(tr2i18n("<html><head/><body><p>Some drives have a sample offset when reading audio CDs. To determine the correct offset for your drive model, you can check the <a href=\"https://www.accuraterip.com/driveoffsets.htm\"><span style=\" text-decoration: underline; color:#2980b9;\">Accuraterip</span></a> database.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("<html><head/><body><p>Specify the maximum number of retry attempts when a faulty sector is encountered.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Max. read retries:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_retriesOnReadError->setToolTip(tr2i18n("<html><head/><body><p>Specify the maximum number of retry attempts when a faulty sector is encountered.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)DeviceWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class DeviceWidgetUI: public Ui_DeviceWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DEVICEWIDGETUI_H

