/********************************************************************************
** Form generated from reading UI file 'remoteserversettingswidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REMOTESERVERSETTINGSWIDGETUI_H
#define UI_REMOTESERVERSETTINGSWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_RemoteServerSettingsWidgetUI
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_upload;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    KUrlRequester *kcfg_url;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *RemoteServerSettingsWidgetUI)
    {
        if (RemoteServerSettingsWidgetUI->objectName().isEmpty())
            RemoteServerSettingsWidgetUI->setObjectName("RemoteServerSettingsWidgetUI");
        RemoteServerSettingsWidgetUI->resize(188, 86);
        gridLayout_2 = new QGridLayout(RemoteServerSettingsWidgetUI);
        gridLayout_2->setObjectName("gridLayout_2");
        groupBox = new QGroupBox(RemoteServerSettingsWidgetUI);
        groupBox->setObjectName("groupBox");
        groupBox->setTitle(QString::fromUtf8(""));
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        kcfg_upload = new QCheckBox(groupBox);
        kcfg_upload->setObjectName("kcfg_upload");

        gridLayout->addWidget(kcfg_upload, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(32, 10, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setEnabled(false);

        horizontalLayout->addWidget(label);

        kcfg_url = new KUrlRequester(groupBox);
        kcfg_url->setObjectName("kcfg_url");
        kcfg_url->setEnabled(false);

        horizontalLayout->addWidget(kcfg_url);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 1);


        gridLayout_2->addWidget(groupBox, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(spacerItem, 1, 0, 1, 1);


        retranslateUi(RemoteServerSettingsWidgetUI);

        QMetaObject::connectSlotsByName(RemoteServerSettingsWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *RemoteServerSettingsWidgetUI)
    {
        kcfg_upload->setText(tr2i18n("Upload files to server", nullptr));
        label->setText(tr2i18n("URL:", nullptr));
        (void)RemoteServerSettingsWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class RemoteServerSettingsWidgetUI: public Ui_RemoteServerSettingsWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REMOTESERVERSETTINGSWIDGETUI_H

