/********************************************************************************
** Form generated from reading UI file 'profiledatasinglefilewidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEDATASINGLEFILEWIDGETUI_H
#define UI_PROFILEDATASINGLEFILEWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProfileDataSingleFileWidgetUI
{
public:
    QGridLayout *gridLayout;
    QLabel *label_scheme;
    QLineEdit *qlineedit_scheme;
    QPushButton *kpushbutton_scheme;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ProfileDataSingleFileWidgetUI)
    {
        if (ProfileDataSingleFileWidgetUI->objectName().isEmpty())
            ProfileDataSingleFileWidgetUI->setObjectName("ProfileDataSingleFileWidgetUI");
        ProfileDataSingleFileWidgetUI->resize(377, 52);
        gridLayout = new QGridLayout(ProfileDataSingleFileWidgetUI);
        gridLayout->setObjectName("gridLayout");
        label_scheme = new QLabel(ProfileDataSingleFileWidgetUI);
        label_scheme->setObjectName("label_scheme");
        label_scheme->setMinimumSize(QSize(100, 0));

        gridLayout->addWidget(label_scheme, 0, 0, 1, 1);

        qlineedit_scheme = new QLineEdit(ProfileDataSingleFileWidgetUI);
        qlineedit_scheme->setObjectName("qlineedit_scheme");

        gridLayout->addWidget(qlineedit_scheme, 0, 1, 1, 1);

        kpushbutton_scheme = new QPushButton(ProfileDataSingleFileWidgetUI);
        kpushbutton_scheme->setObjectName("kpushbutton_scheme");

        gridLayout->addWidget(kpushbutton_scheme, 0, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 3, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 1, 1, 1);


        retranslateUi(ProfileDataSingleFileWidgetUI);

        QMetaObject::connectSlotsByName(ProfileDataSingleFileWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *ProfileDataSingleFileWidgetUI)
    {
        label_scheme->setText(tr2i18n("Name/Scheme:", nullptr));
        qlineedit_scheme->setPlaceholderText(tr2i18n("Please set a scheme", nullptr));
        (void)ProfileDataSingleFileWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class ProfileDataSingleFileWidgetUI: public Ui_ProfileDataSingleFileWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEDATASINGLEFILEWIDGETUI_H

