/********************************************************************************
** Form generated from reading UI file 'opusencwidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPUSENCWIDGETUI_H
#define UI_OPUSENCWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpusEncWidgetUI
{
public:
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label_suffix;
    QLineEdit *qlineedit_suffix;
    QSpacerItem *horizontalSpacer;
    QCheckBox *checkBox_embedcover;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QSpinBox *kintspinbox_bitrate;
    QLabel *label_lowest;
    QLabel *label_highest;
    QSlider *horizontalSlider_bitrate;

    void setupUi(QWidget *OpusEncWidgetUI)
    {
        if (OpusEncWidgetUI->objectName().isEmpty())
            OpusEncWidgetUI->setObjectName("OpusEncWidgetUI");
        OpusEncWidgetUI->resize(430, 300);
        OpusEncWidgetUI->setMinimumSize(QSize(430, 300));
        gridLayout_2 = new QGridLayout(OpusEncWidgetUI);
        gridLayout_2->setObjectName("gridLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_suffix = new QLabel(OpusEncWidgetUI);
        label_suffix->setObjectName("label_suffix");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_suffix->sizePolicy().hasHeightForWidth());
        label_suffix->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label_suffix);

        qlineedit_suffix = new QLineEdit(OpusEncWidgetUI);
        qlineedit_suffix->setObjectName("qlineedit_suffix");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(30);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(qlineedit_suffix->sizePolicy().hasHeightForWidth());
        qlineedit_suffix->setSizePolicy(sizePolicy1);
        qlineedit_suffix->setMaximumSize(QSize(70, 16777215));

        horizontalLayout->addWidget(qlineedit_suffix);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout_2->addLayout(horizontalLayout, 2, 0, 1, 1);

        checkBox_embedcover = new QCheckBox(OpusEncWidgetUI);
        checkBox_embedcover->setObjectName("checkBox_embedcover");

        gridLayout_2->addWidget(checkBox_embedcover, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 3, 0, 1, 1);

        groupBox = new QGroupBox(OpusEncWidgetUI);
        groupBox->setObjectName("groupBox");
        QFont font;
        font.setBold(true);
        groupBox->setFont(font);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        kintspinbox_bitrate = new QSpinBox(groupBox);
        kintspinbox_bitrate->setObjectName("kintspinbox_bitrate");
        kintspinbox_bitrate->setMaximumSize(QSize(90, 16777215));
        QFont font1;
        font1.setBold(false);
        kintspinbox_bitrate->setFont(font1);
        kintspinbox_bitrate->setMinimum(4);
        kintspinbox_bitrate->setMaximum(510);
        kintspinbox_bitrate->setValue(128);

        gridLayout->addWidget(kintspinbox_bitrate, 0, 3, 1, 1);

        label_lowest = new QLabel(groupBox);
        label_lowest->setObjectName("label_lowest");
        QFont font2;
        font2.setBold(false);
        font2.setItalic(true);
        label_lowest->setFont(font2);

        gridLayout->addWidget(label_lowest, 1, 0, 1, 1);

        label_highest = new QLabel(groupBox);
        label_highest->setObjectName("label_highest");
        label_highest->setFont(font2);
        label_highest->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_highest, 1, 1, 1, 2);

        horizontalSlider_bitrate = new QSlider(groupBox);
        horizontalSlider_bitrate->setObjectName("horizontalSlider_bitrate");
        horizontalSlider_bitrate->setMinimum(4);
        horizontalSlider_bitrate->setMaximum(510);
        horizontalSlider_bitrate->setPageStep(10);
        horizontalSlider_bitrate->setValue(128);
        horizontalSlider_bitrate->setOrientation(Qt::Horizontal);
        horizontalSlider_bitrate->setTickPosition(QSlider::TicksBelow);

        gridLayout->addWidget(horizontalSlider_bitrate, 0, 0, 1, 3);


        gridLayout_2->addWidget(groupBox, 0, 0, 1, 1);


        retranslateUi(OpusEncWidgetUI);

        QMetaObject::connectSlotsByName(OpusEncWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *OpusEncWidgetUI)
    {
        label_suffix->setText(tr2i18n("Suffix:", nullptr));
        checkBox_embedcover->setText(tr2i18n("Embed cover in music file", nullptr));
        groupBox->setTitle(tr2i18n("Target bitrate (kbit/s)", nullptr));
        kintspinbox_bitrate->setSpecialValueText(QString());
        kintspinbox_bitrate->setSuffix(tr2i18n(" kbit/s", nullptr));
        kintspinbox_bitrate->setPrefix(QString());
        label_lowest->setText(tr2i18n("Lowest", nullptr));
        label_highest->setText(tr2i18n("Highest", nullptr));
        (void)OpusEncWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class OpusEncWidgetUI: public Ui_OpusEncWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPUSENCWIDGETUI_H

