/********************************************************************************
** Form generated from reading UI file 'schemewizardwidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCHEMEWIZARDWIDGETUI_H
#define UI_SCHEMEWIZARDWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurllabel.h"

QT_BEGIN_NAMESPACE

class Ui_SchemeWizardWidgetUI
{
public:
    QGridLayout *gridLayout;
    QLineEdit *qlineedit_scheme;
    QLabel *label_album_example;
    QLineEdit *qlineedit_album_example;
    QLabel *label_sampler_example;
    QLineEdit *qlineedit_sampler_example;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    KUrlLabel *kurllabel_help;
    QPushButton *kpushbutton_albumartist;
    QPushButton *kpushbutton_albumtitle;
    QPushButton *kpushbutton_trackartist;
    QPushButton *kpushbutton_tracktitle;
    QPushButton *kpushbutton_trackno;
    QPushButton *kpushbutton_cdno;
    QPushButton *kpushbutton_date;
    QPushButton *kpushbutton_genre;
    QPushButton *kpushbutton_suffix;
    QSpacerItem *verticalSpacer;
    QPushButton *kpushbutton_nooftracks;

    void setupUi(QWidget *SchemeWizardWidgetUI)
    {
        if (SchemeWizardWidgetUI->objectName().isEmpty())
            SchemeWizardWidgetUI->setObjectName("SchemeWizardWidgetUI");
        SchemeWizardWidgetUI->resize(395, 322);
        gridLayout = new QGridLayout(SchemeWizardWidgetUI);
        gridLayout->setObjectName("gridLayout");
        qlineedit_scheme = new QLineEdit(SchemeWizardWidgetUI);
        qlineedit_scheme->setObjectName("qlineedit_scheme");

        gridLayout->addWidget(qlineedit_scheme, 0, 0, 1, 4);

        label_album_example = new QLabel(SchemeWizardWidgetUI);
        label_album_example->setObjectName("label_album_example");
        label_album_example->setMaximumSize(QSize(16777215, 21));

        gridLayout->addWidget(label_album_example, 1, 0, 1, 1);

        qlineedit_album_example = new QLineEdit(SchemeWizardWidgetUI);
        qlineedit_album_example->setObjectName("qlineedit_album_example");
        qlineedit_album_example->setEnabled(true);
        QPalette palette;
        QBrush brush(QColor(224, 223, 223, 255));
        brush.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush);
        QBrush brush1(QColor(65, 139, 212, 255));
        brush1.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Highlight, brush1);
        QBrush brush2(QColor(255, 255, 255, 255));
        brush2.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::HighlightedText, brush2);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Highlight, brush1);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::HighlightedText, brush2);
        QBrush brush3(QColor(244, 244, 244, 255));
        brush3.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush3);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Highlight, brush1);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::HighlightedText, brush2);
        qlineedit_album_example->setPalette(palette);
        qlineedit_album_example->setReadOnly(true);

        gridLayout->addWidget(qlineedit_album_example, 2, 0, 1, 4);

        label_sampler_example = new QLabel(SchemeWizardWidgetUI);
        label_sampler_example->setObjectName("label_sampler_example");
        label_sampler_example->setMaximumSize(QSize(16777215, 21));

        gridLayout->addWidget(label_sampler_example, 3, 0, 1, 1);

        qlineedit_sampler_example = new QLineEdit(SchemeWizardWidgetUI);
        qlineedit_sampler_example->setObjectName("qlineedit_sampler_example");
        qlineedit_sampler_example->setEnabled(true);
        QPalette palette1;
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Base, brush);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Highlight, brush1);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::HighlightedText, brush2);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Base, brush);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Highlight, brush1);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::HighlightedText, brush2);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Base, brush3);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Highlight, brush1);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::HighlightedText, brush2);
        qlineedit_sampler_example->setPalette(palette1);
        qlineedit_sampler_example->setReadOnly(true);

        gridLayout->addWidget(qlineedit_sampler_example, 4, 0, 1, 4);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        kurllabel_help = new KUrlLabel(SchemeWizardWidgetUI);
        kurllabel_help->setObjectName("kurllabel_help");
        kurllabel_help->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(kurllabel_help);


        gridLayout->addLayout(horizontalLayout, 5, 0, 1, 4);

        kpushbutton_albumartist = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_albumartist->setObjectName("kpushbutton_albumartist");
        kpushbutton_albumartist->setMinimumSize(QSize(0, 0));
        kpushbutton_albumartist->setMaximumSize(QSize(16777215, 16777215));

        gridLayout->addWidget(kpushbutton_albumartist, 6, 0, 1, 1);

        kpushbutton_albumtitle = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_albumtitle->setObjectName("kpushbutton_albumtitle");
        kpushbutton_albumtitle->setMinimumSize(QSize(0, 0));
        kpushbutton_albumtitle->setMaximumSize(QSize(16777215, 16777215));

        gridLayout->addWidget(kpushbutton_albumtitle, 6, 1, 1, 1);

        kpushbutton_trackartist = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_trackartist->setObjectName("kpushbutton_trackartist");
        kpushbutton_trackartist->setMinimumSize(QSize(0, 0));
        kpushbutton_trackartist->setMaximumSize(QSize(16777215, 16777215));

        gridLayout->addWidget(kpushbutton_trackartist, 6, 2, 1, 1);

        kpushbutton_tracktitle = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_tracktitle->setObjectName("kpushbutton_tracktitle");
        kpushbutton_tracktitle->setMinimumSize(QSize(0, 0));
        kpushbutton_tracktitle->setMaximumSize(QSize(16777215, 16777215));

        gridLayout->addWidget(kpushbutton_tracktitle, 6, 3, 1, 1);

        kpushbutton_trackno = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_trackno->setObjectName("kpushbutton_trackno");

        gridLayout->addWidget(kpushbutton_trackno, 7, 0, 1, 1);

        kpushbutton_cdno = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_cdno->setObjectName("kpushbutton_cdno");

        gridLayout->addWidget(kpushbutton_cdno, 7, 1, 1, 1);

        kpushbutton_date = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_date->setObjectName("kpushbutton_date");

        gridLayout->addWidget(kpushbutton_date, 7, 2, 1, 1);

        kpushbutton_genre = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_genre->setObjectName("kpushbutton_genre");

        gridLayout->addWidget(kpushbutton_genre, 7, 3, 1, 1);

        kpushbutton_suffix = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_suffix->setObjectName("kpushbutton_suffix");

        gridLayout->addWidget(kpushbutton_suffix, 8, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 9, 1, 1, 2);

        kpushbutton_nooftracks = new QPushButton(SchemeWizardWidgetUI);
        kpushbutton_nooftracks->setObjectName("kpushbutton_nooftracks");

        gridLayout->addWidget(kpushbutton_nooftracks, 8, 1, 1, 1);


        retranslateUi(SchemeWizardWidgetUI);

        QMetaObject::connectSlotsByName(SchemeWizardWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *SchemeWizardWidgetUI)
    {
        label_album_example->setText(tr2i18n("Album Example:", nullptr));
        label_sampler_example->setText(tr2i18n("Sampler Example:", nullptr));
        kurllabel_help->setText(tr2i18n("Help", nullptr));
#if QT_CONFIG(tooltip)
        kpushbutton_albumartist->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kpushbutton_albumartist->setText(tr2i18n("Album Artist", nullptr));
#if QT_CONFIG(tooltip)
        kpushbutton_albumtitle->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kpushbutton_albumtitle->setText(tr2i18n("Album Title", nullptr));
#if QT_CONFIG(tooltip)
        kpushbutton_trackartist->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kpushbutton_trackartist->setText(tr2i18n("Track Artist", nullptr));
#if QT_CONFIG(tooltip)
        kpushbutton_tracktitle->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kpushbutton_tracktitle->setText(tr2i18n("Track Title", nullptr));
#if QT_CONFIG(tooltip)
        kpushbutton_trackno->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kpushbutton_trackno->setText(tr2i18n("Track #", nullptr));
#if QT_CONFIG(tooltip)
        kpushbutton_cdno->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kpushbutton_cdno->setText(tr2i18n("CD #", nullptr));
#if QT_CONFIG(tooltip)
        kpushbutton_date->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kpushbutton_date->setText(tr2i18n("Date", nullptr));
#if QT_CONFIG(tooltip)
        kpushbutton_genre->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kpushbutton_genre->setText(tr2i18n("Genre", nullptr));
#if QT_CONFIG(tooltip)
        kpushbutton_suffix->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kpushbutton_suffix->setText(tr2i18n("Suffix", nullptr));
        kpushbutton_nooftracks->setText(tr2i18n("# of Tracks", nullptr));
        (void)SchemeWizardWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class SchemeWizardWidgetUI: public Ui_SchemeWizardWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCHEMEWIZARDWIDGETUI_H

