/********************************************************************************
** Form generated from reading UI file 'profiledatacuesheetwidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEDATACUESHEETWIDGETUI_H
#define UI_PROFILEDATACUESHEETWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProfileDataCueSheetWidgetUI
{
public:
    QGridLayout *gridLayout;
    QLineEdit *qlineedit_scheme;
    QPushButton *kpushbutton_scheme;
    QLabel *label_scheme;
    QSpacerItem *verticalSpacer;
    QCheckBox *checkBox_add_mcn_and_isrc;

    void setupUi(QWidget *ProfileDataCueSheetWidgetUI)
    {
        if (ProfileDataCueSheetWidgetUI->objectName().isEmpty())
            ProfileDataCueSheetWidgetUI->setObjectName("ProfileDataCueSheetWidgetUI");
        ProfileDataCueSheetWidgetUI->resize(336, 80);
        gridLayout = new QGridLayout(ProfileDataCueSheetWidgetUI);
        gridLayout->setObjectName("gridLayout");
        qlineedit_scheme = new QLineEdit(ProfileDataCueSheetWidgetUI);
        qlineedit_scheme->setObjectName("qlineedit_scheme");

        gridLayout->addWidget(qlineedit_scheme, 0, 1, 1, 1);

        kpushbutton_scheme = new QPushButton(ProfileDataCueSheetWidgetUI);
        kpushbutton_scheme->setObjectName("kpushbutton_scheme");

        gridLayout->addWidget(kpushbutton_scheme, 0, 2, 1, 1);

        label_scheme = new QLabel(ProfileDataCueSheetWidgetUI);
        label_scheme->setObjectName("label_scheme");
        label_scheme->setMinimumSize(QSize(100, 0));

        gridLayout->addWidget(label_scheme, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        checkBox_add_mcn_and_isrc = new QCheckBox(ProfileDataCueSheetWidgetUI);
        checkBox_add_mcn_and_isrc->setObjectName("checkBox_add_mcn_and_isrc");
        checkBox_add_mcn_and_isrc->setEnabled(false);

        gridLayout->addWidget(checkBox_add_mcn_and_isrc, 1, 0, 1, 2);


        retranslateUi(ProfileDataCueSheetWidgetUI);

        QMetaObject::connectSlotsByName(ProfileDataCueSheetWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *ProfileDataCueSheetWidgetUI)
    {
        qlineedit_scheme->setPlaceholderText(tr2i18n("Please set a scheme", nullptr));
        label_scheme->setText(tr2i18n("Name/Scheme:", nullptr));
#if QT_CONFIG(tooltip)
        checkBox_add_mcn_and_isrc->setToolTip(tr2i18n("<html><head/><body><p>Write Media Catalog Number (MCN) and International Standard Recording Codes (ISRC, ISO 3901) of the tracks into the cue sheet (if your drive have the capability).</p><p>Depending in your drive it could take a few seconds at the end of your ripping process to fetch those numbers and codes.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        checkBox_add_mcn_and_isrc->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        checkBox_add_mcn_and_isrc->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        checkBox_add_mcn_and_isrc->setText(tr2i18n("Add MCN and ISRC values (if available)", nullptr));
        (void)ProfileDataCueSheetWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class ProfileDataCueSheetWidgetUI: public Ui_ProfileDataCueSheetWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEDATACUESHEETWIDGETUI_H

