/********************************************************************************
** Form generated from reading UI file 'cddaheaderdatawidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CDDAHEADERDATAWIDGETUI_H
#define UI_CDDAHEADERDATAWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_CDDAHeaderDataWidgetUI
{
public:
    QGridLayout *gridLayout;
    QCheckBox *checkBox_various;
    QCheckBox *checkBox_multicd;
    QSpacerItem *horizontalSpacer;
    QLabel *label_artist;
    QLineEdit *qlineedit_artist;
    QLabel *label_title;
    QLineEdit *qlineedit_title;
    QLabel *label_cdnum;
    QSpinBox *kintspinbox_cdnum;
    QLabel *label;
    QSpinBox *kintspinbox_trackoffset;
    QLabel *label_genre;
    KComboBox *kcombobox_genre;
    QLabel *label_year;
    QSpinBox *kintspinbox_year;
    QLabel *label_extdata;
    KTextEdit *ktextedit_extdata;
    QLabel *label_discid;
    QLineEdit *qlineedit_cddbdiscid;

    void setupUi(QWidget *CDDAHeaderDataWidgetUI)
    {
        if (CDDAHeaderDataWidgetUI->objectName().isEmpty())
            CDDAHeaderDataWidgetUI->setObjectName("CDDAHeaderDataWidgetUI");
        CDDAHeaderDataWidgetUI->resize(309, 393);
        gridLayout = new QGridLayout(CDDAHeaderDataWidgetUI);
        gridLayout->setObjectName("gridLayout");
        checkBox_various = new QCheckBox(CDDAHeaderDataWidgetUI);
        checkBox_various->setObjectName("checkBox_various");

        gridLayout->addWidget(checkBox_various, 0, 0, 1, 2);

        checkBox_multicd = new QCheckBox(CDDAHeaderDataWidgetUI);
        checkBox_multicd->setObjectName("checkBox_multicd");

        gridLayout->addWidget(checkBox_multicd, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(62, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        label_artist = new QLabel(CDDAHeaderDataWidgetUI);
        label_artist->setObjectName("label_artist");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_artist->sizePolicy().hasHeightForWidth());
        label_artist->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_artist, 1, 0, 1, 1);

        qlineedit_artist = new QLineEdit(CDDAHeaderDataWidgetUI);
        qlineedit_artist->setObjectName("qlineedit_artist");

        gridLayout->addWidget(qlineedit_artist, 1, 1, 1, 3);

        label_title = new QLabel(CDDAHeaderDataWidgetUI);
        label_title->setObjectName("label_title");
        sizePolicy.setHeightForWidth(label_title->sizePolicy().hasHeightForWidth());
        label_title->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_title, 2, 0, 1, 1);

        qlineedit_title = new QLineEdit(CDDAHeaderDataWidgetUI);
        qlineedit_title->setObjectName("qlineedit_title");

        gridLayout->addWidget(qlineedit_title, 2, 1, 1, 3);

        label_cdnum = new QLabel(CDDAHeaderDataWidgetUI);
        label_cdnum->setObjectName("label_cdnum");

        gridLayout->addWidget(label_cdnum, 3, 0, 1, 1);

        kintspinbox_cdnum = new QSpinBox(CDDAHeaderDataWidgetUI);
        kintspinbox_cdnum->setObjectName("kintspinbox_cdnum");
        kintspinbox_cdnum->setMinimum(1);

        gridLayout->addWidget(kintspinbox_cdnum, 3, 1, 1, 3);

        label = new QLabel(CDDAHeaderDataWidgetUI);
        label->setObjectName("label");

        gridLayout->addWidget(label, 4, 0, 1, 1);

        kintspinbox_trackoffset = new QSpinBox(CDDAHeaderDataWidgetUI);
        kintspinbox_trackoffset->setObjectName("kintspinbox_trackoffset");
        kintspinbox_trackoffset->setMaximum(99999);

        gridLayout->addWidget(kintspinbox_trackoffset, 4, 1, 1, 3);

        label_genre = new QLabel(CDDAHeaderDataWidgetUI);
        label_genre->setObjectName("label_genre");
        sizePolicy.setHeightForWidth(label_genre->sizePolicy().hasHeightForWidth());
        label_genre->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_genre, 5, 0, 1, 1);

        kcombobox_genre = new KComboBox(CDDAHeaderDataWidgetUI);
        kcombobox_genre->setObjectName("kcombobox_genre");
        kcombobox_genre->setEditable(true);
        kcombobox_genre->setAutoCompletion(false);

        gridLayout->addWidget(kcombobox_genre, 5, 1, 1, 3);

        label_year = new QLabel(CDDAHeaderDataWidgetUI);
        label_year->setObjectName("label_year");
        sizePolicy.setHeightForWidth(label_year->sizePolicy().hasHeightForWidth());
        label_year->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_year, 6, 0, 1, 1);

        kintspinbox_year = new QSpinBox(CDDAHeaderDataWidgetUI);
        kintspinbox_year->setObjectName("kintspinbox_year");
        kintspinbox_year->setMinimum(-3000);
        kintspinbox_year->setMaximum(3000);
        kintspinbox_year->setValue(2004);

        gridLayout->addWidget(kintspinbox_year, 6, 1, 1, 3);

        label_extdata = new QLabel(CDDAHeaderDataWidgetUI);
        label_extdata->setObjectName("label_extdata");
        sizePolicy.setHeightForWidth(label_extdata->sizePolicy().hasHeightForWidth());
        label_extdata->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_extdata, 7, 0, 1, 1);

        ktextedit_extdata = new KTextEdit(CDDAHeaderDataWidgetUI);
        ktextedit_extdata->setObjectName("ktextedit_extdata");

        gridLayout->addWidget(ktextedit_extdata, 7, 1, 1, 3);

        label_discid = new QLabel(CDDAHeaderDataWidgetUI);
        label_discid->setObjectName("label_discid");
        sizePolicy.setHeightForWidth(label_discid->sizePolicy().hasHeightForWidth());
        label_discid->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_discid, 8, 0, 1, 1);

        qlineedit_cddbdiscid = new QLineEdit(CDDAHeaderDataWidgetUI);
        qlineedit_cddbdiscid->setObjectName("qlineedit_cddbdiscid");
        qlineedit_cddbdiscid->setEnabled(true);
        qlineedit_cddbdiscid->setReadOnly(true);

        gridLayout->addWidget(qlineedit_cddbdiscid, 8, 1, 1, 3);

        QWidget::setTabOrder(checkBox_various, checkBox_multicd);
        QWidget::setTabOrder(checkBox_multicd, qlineedit_artist);
        QWidget::setTabOrder(qlineedit_artist, qlineedit_title);
        QWidget::setTabOrder(qlineedit_title, kintspinbox_cdnum);
        QWidget::setTabOrder(kintspinbox_cdnum, kintspinbox_trackoffset);
        QWidget::setTabOrder(kintspinbox_trackoffset, kcombobox_genre);
        QWidget::setTabOrder(kcombobox_genre, kintspinbox_year);
        QWidget::setTabOrder(kintspinbox_year, ktextedit_extdata);

        retranslateUi(CDDAHeaderDataWidgetUI);

        QMetaObject::connectSlotsByName(CDDAHeaderDataWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *CDDAHeaderDataWidgetUI)
    {
        checkBox_various->setText(tr2i18n("Various Artists", nullptr));
        checkBox_multicd->setText(tr2i18n("Multi CD", nullptr));
        label_artist->setText(tr2i18n("Artist:", nullptr));
        label_title->setText(tr2i18n("Title:", nullptr));
        label_cdnum->setText(tr2i18n("CD Number:", nullptr));
        label->setText(tr2i18n("Track Offset:", nullptr));
        label_genre->setText(tr2i18n("Genre:", nullptr));
        label_year->setText(tr2i18n("Year:", nullptr));
        label_extdata->setText(tr2i18n("Additional\n"
"Information:", nullptr));
        label_discid->setText(tr2i18n("CDDB disc ID:", nullptr));
        qlineedit_cddbdiscid->setText(tr2i18n("0x00000000", nullptr));
        (void)CDDAHeaderDataWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class CDDAHeaderDataWidgetUI: public Ui_CDDAHeaderDataWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CDDAHEADERDATAWIDGETUI_H

