/********************************************************************************
** Form generated from reading UI file 'logviewwidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOGVIEWWIDGETUI_H
#define UI_LOGVIEWWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_LogViewWidgetUI
{
public:
    QGridLayout *gridLayout;
    KTextEdit *ktextedit;

    void setupUi(QWidget *LogViewWidgetUI)
    {
        if (LogViewWidgetUI->objectName().isEmpty())
            LogViewWidgetUI->setObjectName("LogViewWidgetUI");
        LogViewWidgetUI->resize(500, 300);
        LogViewWidgetUI->setMinimumSize(QSize(500, 300));
        gridLayout = new QGridLayout(LogViewWidgetUI);
        gridLayout->setObjectName("gridLayout");
        ktextedit = new KTextEdit(LogViewWidgetUI);
        ktextedit->setObjectName("ktextedit");
        ktextedit->setReadOnly(true);

        gridLayout->addWidget(ktextedit, 0, 0, 1, 1);


        retranslateUi(LogViewWidgetUI);

        QMetaObject::connectSlotsByName(LogViewWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *LogViewWidgetUI)
    {
        (void)LogViewWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class LogViewWidgetUI: public Ui_LogViewWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOGVIEWWIDGETUI_H

