/********************************************************************************
** Form generated from reading UI file 'profiledatahashlistwidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEDATAHASHLISTWIDGETUI_H
#define UI_PROFILEDATAHASHLISTWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ProfileDataHashlistWidgetUI
{
public:
    QGridLayout *gridLayout;
    QLabel *label_format;
    KComboBox *kcombobox_format;
    QLabel *label_scheme;
    QLineEdit *qlineedit_scheme;
    QPushButton *kpushbutton_scheme;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ProfileDataHashlistWidgetUI)
    {
        if (ProfileDataHashlistWidgetUI->objectName().isEmpty())
            ProfileDataHashlistWidgetUI->setObjectName("ProfileDataHashlistWidgetUI");
        ProfileDataHashlistWidgetUI->resize(377, 90);
        gridLayout = new QGridLayout(ProfileDataHashlistWidgetUI);
        gridLayout->setObjectName("gridLayout");
        label_format = new QLabel(ProfileDataHashlistWidgetUI);
        label_format->setObjectName("label_format");
        label_format->setMinimumSize(QSize(100, 0));

        gridLayout->addWidget(label_format, 0, 0, 1, 1);

        kcombobox_format = new KComboBox(ProfileDataHashlistWidgetUI);
        kcombobox_format->setObjectName("kcombobox_format");

        gridLayout->addWidget(kcombobox_format, 0, 1, 1, 1);

        label_scheme = new QLabel(ProfileDataHashlistWidgetUI);
        label_scheme->setObjectName("label_scheme");
        label_scheme->setMinimumSize(QSize(100, 0));

        gridLayout->addWidget(label_scheme, 1, 0, 1, 1);

        qlineedit_scheme = new QLineEdit(ProfileDataHashlistWidgetUI);
        qlineedit_scheme->setObjectName("qlineedit_scheme");

        gridLayout->addWidget(qlineedit_scheme, 1, 1, 1, 1);

        kpushbutton_scheme = new QPushButton(ProfileDataHashlistWidgetUI);
        kpushbutton_scheme->setObjectName("kpushbutton_scheme");

        gridLayout->addWidget(kpushbutton_scheme, 1, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 3, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 1, 1, 1);


        retranslateUi(ProfileDataHashlistWidgetUI);

        QMetaObject::connectSlotsByName(ProfileDataHashlistWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *ProfileDataHashlistWidgetUI)
    {
        label_format->setText(tr2i18n("Format:", nullptr));
        label_scheme->setText(tr2i18n("Name/Scheme:", nullptr));
        qlineedit_scheme->setPlaceholderText(tr2i18n("Please set a scheme", nullptr));
        (void)ProfileDataHashlistWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class ProfileDataHashlistWidgetUI: public Ui_ProfileDataHashlistWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEDATAHASHLISTWIDGETUI_H

