/********************************************************************************
** Form generated from reading UI file 'profiledatainfowidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEDATAINFOWIDGETUI_H
#define UI_PROFILEDATAINFOWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktextedit.h"
#include "kurllabel.h"

QT_BEGIN_NAMESPACE

class Ui_ProfileDataInfoWidgetUI
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_text;
    QPushButton *kpushbutton_load;
    QPushButton *kpushbutton_save;
    KTextEdit *ktextedit_text;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_2;
    KUrlLabel *kurllabel_help;
    QHBoxLayout *horizontalLayout;
    QLabel *label_suffix;
    QLineEdit *qlineedit_suffix;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_scheme;
    QLineEdit *qlineedit_scheme;
    QPushButton *kpushbutton_scheme;

    void setupUi(QWidget *ProfileDataInfoWidgetUI)
    {
        if (ProfileDataInfoWidgetUI->objectName().isEmpty())
            ProfileDataInfoWidgetUI->setObjectName("ProfileDataInfoWidgetUI");
        ProfileDataInfoWidgetUI->resize(263, 251);
        gridLayout = new QGridLayout(ProfileDataInfoWidgetUI);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_text = new QLabel(ProfileDataInfoWidgetUI);
        label_text->setObjectName("label_text");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_text->sizePolicy().hasHeightForWidth());
        label_text->setSizePolicy(sizePolicy);

        horizontalLayout_3->addWidget(label_text);

        kpushbutton_load = new QPushButton(ProfileDataInfoWidgetUI);
        kpushbutton_load->setObjectName("kpushbutton_load");

        horizontalLayout_3->addWidget(kpushbutton_load);

        kpushbutton_save = new QPushButton(ProfileDataInfoWidgetUI);
        kpushbutton_save->setObjectName("kpushbutton_save");

        horizontalLayout_3->addWidget(kpushbutton_save);


        gridLayout->addLayout(horizontalLayout_3, 0, 0, 1, 1);

        ktextedit_text = new KTextEdit(ProfileDataInfoWidgetUI);
        ktextedit_text->setObjectName("ktextedit_text");

        gridLayout->addWidget(ktextedit_text, 1, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);

        kurllabel_help = new KUrlLabel(ProfileDataInfoWidgetUI);
        kurllabel_help->setObjectName("kurllabel_help");
        kurllabel_help->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_4->addWidget(kurllabel_help);


        gridLayout->addLayout(horizontalLayout_4, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_suffix = new QLabel(ProfileDataInfoWidgetUI);
        label_suffix->setObjectName("label_suffix");

        horizontalLayout->addWidget(label_suffix);

        qlineedit_suffix = new QLineEdit(ProfileDataInfoWidgetUI);
        qlineedit_suffix->setObjectName("qlineedit_suffix");

        horizontalLayout->addWidget(qlineedit_suffix);

        horizontalSpacer = new QSpacerItem(227, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 3, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_scheme = new QLabel(ProfileDataInfoWidgetUI);
        label_scheme->setObjectName("label_scheme");

        horizontalLayout_2->addWidget(label_scheme);

        qlineedit_scheme = new QLineEdit(ProfileDataInfoWidgetUI);
        qlineedit_scheme->setObjectName("qlineedit_scheme");
        sizePolicy.setHeightForWidth(qlineedit_scheme->sizePolicy().hasHeightForWidth());
        qlineedit_scheme->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(qlineedit_scheme);

        kpushbutton_scheme = new QPushButton(ProfileDataInfoWidgetUI);
        kpushbutton_scheme->setObjectName("kpushbutton_scheme");

        horizontalLayout_2->addWidget(kpushbutton_scheme);


        gridLayout->addLayout(horizontalLayout_2, 4, 0, 1, 1);


        retranslateUi(ProfileDataInfoWidgetUI);

        QMetaObject::connectSlotsByName(ProfileDataInfoWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *ProfileDataInfoWidgetUI)
    {
        label_text->setText(tr2i18n("Information text:", nullptr));
        kurllabel_help->setText(tr2i18n("Help", nullptr));
        label_suffix->setText(tr2i18n("Suffix:", nullptr));
        label_scheme->setText(tr2i18n("Scheme:", nullptr));
        qlineedit_scheme->setPlaceholderText(tr2i18n("Please set a scheme", nullptr));
        (void)ProfileDataInfoWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class ProfileDataInfoWidgetUI: public Ui_ProfileDataInfoWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEDATAINFOWIDGETUI_H

