/********************************************************************************
** Form generated from reading UI file 'wavewidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WAVEWIDGETUI_H
#define UI_WAVEWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WAVEWidgetUI
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_suffix;
    QLineEdit *qlineedit_suffix;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *WAVEWidgetUI)
    {
        if (WAVEWidgetUI->objectName().isEmpty())
            WAVEWidgetUI->setObjectName("WAVEWidgetUI");
        WAVEWidgetUI->resize(430, 300);
        WAVEWidgetUI->setMinimumSize(QSize(430, 300));
        gridLayout = new QGridLayout(WAVEWidgetUI);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_suffix = new QLabel(WAVEWidgetUI);
        label_suffix->setObjectName("label_suffix");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_suffix->sizePolicy().hasHeightForWidth());
        label_suffix->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label_suffix);

        qlineedit_suffix = new QLineEdit(WAVEWidgetUI);
        qlineedit_suffix->setObjectName("qlineedit_suffix");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(30);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(qlineedit_suffix->sizePolicy().hasHeightForWidth());
        qlineedit_suffix->setSizePolicy(sizePolicy1);
        qlineedit_suffix->setMaximumSize(QSize(70, 16777215));

        horizontalLayout->addWidget(qlineedit_suffix);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 2, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);


        retranslateUi(WAVEWidgetUI);

        QMetaObject::connectSlotsByName(WAVEWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *WAVEWidgetUI)
    {
        label_suffix->setText(tr2i18n("Suffix:", nullptr));
        (void)WAVEWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class WAVEWidgetUI: public Ui_WAVEWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WAVEWIDGETUI_H

