/****************************************************************************
** Meta object code from reading C++ file 'audex.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../audex-26.04.1/core/audex.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'audex.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8AudexJobE_t {};
} // unnamed namespace

template <> constexpr inline auto AudexJob::qt_create_metaobjectdata<qt_meta_tag_ZN8AudexJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AudexJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AudexJob, qt_meta_tag_ZN8AudexJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AudexJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8AudexJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8AudexJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8AudexJobE_t>.metaTypes,
    nullptr
} };

void AudexJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AudexJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *AudexJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AudexJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8AudexJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AudexJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9AudexJobsE_t {};
} // unnamed namespace

template <> constexpr inline auto AudexJobs::qt_create_metaobjectdata<qt_meta_tag_ZN9AudexJobsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AudexJobs",
        "newJobAvailable",
        "",
        "addNewJob",
        "sourceFilename",
        "targetFilename",
        "trackno"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newJobAvailable'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addNewJob'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::Int, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AudexJobs, qt_meta_tag_ZN9AudexJobsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AudexJobs::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9AudexJobsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9AudexJobsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9AudexJobsE_t>.metaTypes,
    nullptr
} };

void AudexJobs::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AudexJobs *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newJobAvailable(); break;
        case 1: _t->addNewJob((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AudexJobs::*)()>(_a, &AudexJobs::newJobAvailable, 0))
            return;
    }
}

const QMetaObject *AudexJobs::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AudexJobs::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9AudexJobsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AudexJobs::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void AudexJobs::newJobAvailable()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN5AudexE_t {};
} // unnamed namespace

template <> constexpr inline auto Audex::qt_create_metaobjectdata<qt_meta_tag_ZN5AudexE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Audex",
        "changedExtractTrack",
        "",
        "no",
        "total",
        "artist",
        "title",
        "changedEncodeTrack",
        "filename",
        "progressExtractTrack",
        "percent",
        "progressExtractOverall",
        "progressEncodeTrack",
        "progressEncodeOverall",
        "speedExtract",
        "times",
        "speedEncode",
        "finished",
        "successful",
        "timeout",
        "error",
        "message",
        "details",
        "warning",
        "info",
        "start",
        "cancel",
        "extractLog",
        "encoderLog",
        "start_extract",
        "finish_extract",
        "start_encode",
        "finish_encode",
        "calculate_speed_extract",
        "calculate_speed_encode",
        "progress_extract",
        "percent_of_track",
        "sector",
        "overall_sectors_read",
        "progress_encode",
        "write_to_wave",
        "data",
        "slot_error",
        "slot_warning",
        "slot_info",
        "check_if_thread_still_running"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changedExtractTrack'
        QtMocHelpers::SignalData<void(int, int, const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'changedEncodeTrack'
        QtMocHelpers::SignalData<void(int, int, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'progressExtractTrack'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'progressExtractOverall'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'progressEncodeTrack'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'progressEncodeOverall'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'speedExtract'
        QtMocHelpers::SignalData<void(double)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 15 },
        }}),
        // Signal 'speedEncode'
        QtMocHelpers::SignalData<void(double)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 15 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'timeout'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'warning'
        QtMocHelpers::SignalData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'extractLog'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'encoderLog'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start_extract'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'finish_extract'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'start_encode'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'finish_encode'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'calculate_speed_extract'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'calculate_speed_encode'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'progress_extract'
        QtMocHelpers::SlotData<void(int, int, int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 37 }, { QMetaType::Int, 38 },
        }}),
        // Slot 'progress_encode'
        QtMocHelpers::SlotData<void(int)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'write_to_wave'
        QtMocHelpers::SlotData<void(const QByteArray &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 41 },
        }}),
        // Slot 'slot_error'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'slot_error'
        QtMocHelpers::SlotData<void(const QString &)>(42, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'slot_warning'
        QtMocHelpers::SlotData<void(const QString &)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'slot_info'
        QtMocHelpers::SlotData<void(const QString &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'check_if_thread_still_running'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Audex, qt_meta_tag_ZN5AudexE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Audex::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5AudexE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5AudexE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5AudexE_t>.metaTypes,
    nullptr
} };

void Audex::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Audex *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changedExtractTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 1: _t->changedEncodeTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->progressExtractTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->progressExtractOverall((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->progressEncodeTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->progressEncodeOverall((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->speedExtract((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 7: _t->speedEncode((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->finished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->timeout(); break;
        case 10: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->warning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->start(); break;
        case 15: _t->cancel(); break;
        case 16: _t->extractLog(); break;
        case 17: _t->encoderLog(); break;
        case 18: _t->start_extract(); break;
        case 19: _t->finish_extract(); break;
        case 20: _t->start_encode(); break;
        case 21: _t->finish_encode(); break;
        case 22: _t->calculate_speed_extract(); break;
        case 23: _t->calculate_speed_encode(); break;
        case 24: _t->progress_extract((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 25: _t->progress_encode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->write_to_wave((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 27: _t->slot_error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 28: _t->slot_error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->slot_warning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->slot_info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->check_if_thread_still_running(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(int , int , const QString & , const QString & )>(_a, &Audex::changedExtractTrack, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(int , int , const QString & )>(_a, &Audex::changedEncodeTrack, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(int )>(_a, &Audex::progressExtractTrack, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(int )>(_a, &Audex::progressExtractOverall, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(int )>(_a, &Audex::progressEncodeTrack, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(int )>(_a, &Audex::progressEncodeOverall, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(double )>(_a, &Audex::speedExtract, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(double )>(_a, &Audex::speedEncode, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(bool )>(_a, &Audex::finished, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)()>(_a, &Audex::timeout, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(const QString & , const QString & )>(_a, &Audex::error, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(const QString & )>(_a, &Audex::warning, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Audex::*)(const QString & )>(_a, &Audex::info, 13))
            return;
    }
}

const QMetaObject *Audex::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Audex::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5AudexE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Audex::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void Audex::changedExtractTrack(int _t1, int _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void Audex::changedEncodeTrack(int _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Audex::progressExtractTrack(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Audex::progressExtractOverall(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Audex::progressEncodeTrack(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Audex::progressEncodeOverall(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Audex::speedExtract(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Audex::speedEncode(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Audex::finished(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Audex::timeout()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Audex::error(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 12
void Audex::warning(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Audex::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
