/********************************************************************************
** Form generated from reading UI file 'profiledatacoverwidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEDATACOVERWIDGETUI_H
#define UI_PROFILEDATACOVERWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ProfileDataCoverWidgetUI
{
public:
    QGridLayout *gridLayout;
    QCheckBox *checkBox_scale;
    QSpinBox *kintspinbox_x;
    QLabel *label_x;
    QSpinBox *kintspinbox_y;
    QLabel *label_format;
    KComboBox *kcombobox_format;
    QLabel *label_scheme;
    QLineEdit *qlineedit_scheme;
    QPushButton *kpushbutton_scheme;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ProfileDataCoverWidgetUI)
    {
        if (ProfileDataCoverWidgetUI->objectName().isEmpty())
            ProfileDataCoverWidgetUI->setObjectName("ProfileDataCoverWidgetUI");
        ProfileDataCoverWidgetUI->resize(383, 128);
        gridLayout = new QGridLayout(ProfileDataCoverWidgetUI);
        gridLayout->setObjectName("gridLayout");
        checkBox_scale = new QCheckBox(ProfileDataCoverWidgetUI);
        checkBox_scale->setObjectName("checkBox_scale");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(checkBox_scale->sizePolicy().hasHeightForWidth());
        checkBox_scale->setSizePolicy(sizePolicy);

        gridLayout->addWidget(checkBox_scale, 0, 0, 1, 2);

        kintspinbox_x = new QSpinBox(ProfileDataCoverWidgetUI);
        kintspinbox_x->setObjectName("kintspinbox_x");
        sizePolicy.setHeightForWidth(kintspinbox_x->sizePolicy().hasHeightForWidth());
        kintspinbox_x->setSizePolicy(sizePolicy);
        kintspinbox_x->setMaximum(10000);

        gridLayout->addWidget(kintspinbox_x, 0, 2, 1, 1);

        label_x = new QLabel(ProfileDataCoverWidgetUI);
        label_x->setObjectName("label_x");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_x->sizePolicy().hasHeightForWidth());
        label_x->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_x, 0, 3, 1, 1);

        kintspinbox_y = new QSpinBox(ProfileDataCoverWidgetUI);
        kintspinbox_y->setObjectName("kintspinbox_y");
        sizePolicy.setHeightForWidth(kintspinbox_y->sizePolicy().hasHeightForWidth());
        kintspinbox_y->setSizePolicy(sizePolicy);
        kintspinbox_y->setMaximum(10000);

        gridLayout->addWidget(kintspinbox_y, 0, 4, 1, 1);

        label_format = new QLabel(ProfileDataCoverWidgetUI);
        label_format->setObjectName("label_format");
        label_format->setMinimumSize(QSize(80, 0));

        gridLayout->addWidget(label_format, 1, 0, 1, 1);

        kcombobox_format = new KComboBox(ProfileDataCoverWidgetUI);
        kcombobox_format->setObjectName("kcombobox_format");

        gridLayout->addWidget(kcombobox_format, 1, 1, 1, 4);

        label_scheme = new QLabel(ProfileDataCoverWidgetUI);
        label_scheme->setObjectName("label_scheme");
        label_scheme->setMinimumSize(QSize(80, 0));

        gridLayout->addWidget(label_scheme, 2, 0, 1, 1);

        qlineedit_scheme = new QLineEdit(ProfileDataCoverWidgetUI);
        qlineedit_scheme->setObjectName("qlineedit_scheme");

        gridLayout->addWidget(qlineedit_scheme, 2, 1, 1, 4);

        kpushbutton_scheme = new QPushButton(ProfileDataCoverWidgetUI);
        kpushbutton_scheme->setObjectName("kpushbutton_scheme");

        gridLayout->addWidget(kpushbutton_scheme, 2, 5, 1, 1);

        verticalSpacer = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 2, 1, 1);


        retranslateUi(ProfileDataCoverWidgetUI);

        QMetaObject::connectSlotsByName(ProfileDataCoverWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *ProfileDataCoverWidgetUI)
    {
        checkBox_scale->setText(tr2i18n("Scale before store:", nullptr));
        label_x->setText(tr2i18n("\303\227", nullptr));
        label_format->setText(tr2i18n("Format:", nullptr));
        label_scheme->setText(tr2i18n("Cover scheme:", nullptr));
        qlineedit_scheme->setPlaceholderText(tr2i18n("Please set a scheme", nullptr));
        (void)ProfileDataCoverWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class ProfileDataCoverWidgetUI: public Ui_ProfileDataCoverWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEDATACOVERWIDGETUI_H

