/****************************************************************************
** Meta object code from reading C++ file 'cddaextractthread.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../audex-26.04.1/utils/cddaextractthread.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cddaextractthread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17CDDAExtractThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto CDDAExtractThread::qt_create_metaobjectdata<qt_meta_tag_ZN17CDDAExtractThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CDDAExtractThread",
        "output",
        "",
        "progress",
        "percent",
        "sector",
        "sectorsOverall",
        "error",
        "message",
        "details",
        "warning",
        "info",
        "start",
        "cancel",
        "enableParanoiaMode",
        "enable",
        "paranoiaMode",
        "enableSkipReadErrors",
        "skip",
        "skipReadErrorsEnabled",
        "setParanoiaMaxRetriesOnReadError",
        "max_retries",
        "paranoiaMaxRetriesOnReadError",
        "setSampleShift",
        "shift",
        "setTimestampsIntoLog",
        "set",
        "setTrackToRip",
        "track_t",
        "t",
        "skipTrack",
        "isProcessing",
        "log",
        "reset",
        "slot_error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'output'
        QtMocHelpers::SignalData<void(const QByteArray &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 2 },
        }}),
        // Signal 'progress'
        QtMocHelpers::SignalData<void(const int, const int, const int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'warning'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableParanoiaMode'
        QtMocHelpers::SlotData<void(const bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'enableParanoiaMode'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'paranoiaMode'
        QtMocHelpers::SlotData<bool() const>(16, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'enableSkipReadErrors'
        QtMocHelpers::SlotData<void(const bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'enableSkipReadErrors'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'skipReadErrorsEnabled'
        QtMocHelpers::SlotData<bool() const>(19, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setParanoiaMaxRetriesOnReadError'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'paranoiaMaxRetriesOnReadError'
        QtMocHelpers::SlotData<int() const>(22, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setSampleShift'
        QtMocHelpers::SlotData<void(const int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setTimestampsIntoLog'
        QtMocHelpers::SlotData<void(const bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setTrackToRip'
        QtMocHelpers::SlotData<void(const track_t)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'skipTrack'
        QtMocHelpers::SlotData<void(const track_t)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'isProcessing'
        QtMocHelpers::SlotData<bool()>(31, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'log'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slot_error'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CDDAExtractThread, qt_meta_tag_ZN17CDDAExtractThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CDDAExtractThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CDDAExtractThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CDDAExtractThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CDDAExtractThreadE_t>.metaTypes,
    nullptr
} };

void CDDAExtractThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CDDAExtractThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->output((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 1: _t->progress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->warning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->start(); break;
        case 7: _t->cancel(); break;
        case 8: _t->enableParanoiaMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->enableParanoiaMode(); break;
        case 10: { bool _r = _t->paranoiaMode();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->enableSkipReadErrors((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->enableSkipReadErrors(); break;
        case 13: { bool _r = _t->skipReadErrorsEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setParanoiaMaxRetriesOnReadError((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: { int _r = _t->paranoiaMaxRetriesOnReadError();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setSampleShift((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setTimestampsIntoLog((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setTrackToRip((*reinterpret_cast<std::add_pointer_t<track_t>>(_a[1]))); break;
        case 19: _t->skipTrack((*reinterpret_cast<std::add_pointer_t<track_t>>(_a[1]))); break;
        case 20: { bool _r = _t->isProcessing();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->log(); break;
        case 22: _t->reset(); break;
        case 23: _t->slot_error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CDDAExtractThread::*)(const QByteArray & )>(_a, &CDDAExtractThread::output, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAExtractThread::*)(const int , const int , const int )>(_a, &CDDAExtractThread::progress, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAExtractThread::*)(const QString & , const QString & )>(_a, &CDDAExtractThread::error, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAExtractThread::*)(const QString & )>(_a, &CDDAExtractThread::warning, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAExtractThread::*)(const QString & )>(_a, &CDDAExtractThread::info, 5))
            return;
    }
}

const QMetaObject *CDDAExtractThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CDDAExtractThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CDDAExtractThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int CDDAExtractThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void CDDAExtractThread::output(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void CDDAExtractThread::progress(const int _t1, const int _t2, const int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void CDDAExtractThread::error(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 4
void CDDAExtractThread::warning(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void CDDAExtractThread::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
