/****************************************************************************
** Meta object code from reading C++ file 'profiledatadialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../audex-26.04.1/dialogs/profiledatadialog.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'profiledatadialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17ProfileDataDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto ProfileDataDialog::qt_create_metaobjectdata<qt_meta_tag_ZN17ProfileDataDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProfileDataDialog",
        "set_encoder",
        "",
        "encoder",
        "set_encoder_by_combobox",
        "index",
        "trigger_changed",
        "enable_settings_cover",
        "enabled",
        "enable_settings_playlist",
        "enable_settings_info",
        "enable_settings_hashlist",
        "enable_settings_cuesheet",
        "enable_settings_logfile",
        "enable_settings_singlefile",
        "disable_playlist",
        "disabled",
        "enable_filenames",
        "disable_filenames",
        "scheme_wizard",
        "cover_settings",
        "playlist_settings",
        "info_settings",
        "hashlist_settings",
        "cuesheet_settings",
        "logfile_settings",
        "singlefile_settings",
        "slotAccepted",
        "slotApplied",
        "slotRejected"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'set_encoder'
        QtMocHelpers::SlotData<void(const int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'set_encoder_by_combobox'
        QtMocHelpers::SlotData<void(const int)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'trigger_changed'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enable_settings_cover'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'enable_settings_playlist'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'enable_settings_info'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'enable_settings_hashlist'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'enable_settings_cuesheet'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'enable_settings_logfile'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'enable_settings_singlefile'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'disable_playlist'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'enable_filenames'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'disable_filenames'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'scheme_wizard'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cover_settings'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playlist_settings'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'info_settings'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'hashlist_settings'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cuesheet_settings'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'logfile_settings'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'singlefile_settings'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAccepted'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotApplied'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRejected'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProfileDataDialog, qt_meta_tag_ZN17ProfileDataDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProfileDataDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ProfileDataDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ProfileDataDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ProfileDataDialogE_t>.metaTypes,
    nullptr
} };

void ProfileDataDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProfileDataDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->set_encoder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->set_encoder_by_combobox((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->trigger_changed(); break;
        case 3: _t->enable_settings_cover((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->enable_settings_playlist((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->enable_settings_info((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->enable_settings_hashlist((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->enable_settings_cuesheet((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->enable_settings_logfile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->enable_settings_singlefile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->disable_playlist((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->enable_filenames((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->disable_filenames((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->scheme_wizard(); break;
        case 14: _t->cover_settings(); break;
        case 15: _t->playlist_settings(); break;
        case 16: _t->info_settings(); break;
        case 17: _t->hashlist_settings(); break;
        case 18: _t->cuesheet_settings(); break;
        case 19: _t->logfile_settings(); break;
        case 20: _t->singlefile_settings(); break;
        case 21: _t->slotAccepted(); break;
        case 22: _t->slotApplied(); break;
        case 23: _t->slotRejected(); break;
        default: ;
        }
    }
}

const QMetaObject *ProfileDataDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProfileDataDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ProfileDataDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int ProfileDataDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}
QT_WARNING_POP
