/****************************************************************************
** Meta object code from reading C++ file 'cddamodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../audex-26.04.1/models/cddamodel.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cddamodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9CDDAModelE_t {};
} // unnamed namespace

template <> constexpr inline auto CDDAModel::qt_create_metaobjectdata<qt_meta_tag_ZN9CDDAModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CDDAModel",
        "audioDiscDetected",
        "",
        "audioDiscRemoved",
        "cddbLookupStarted",
        "cddbLookupDone",
        "successful",
        "cddbDataModified",
        "cddbDataSubmited",
        "hasSelection",
        "has_selection",
        "selectionChanged",
        "num_selected",
        "lookupCDDB",
        "submitCDDB",
        "eject",
        "new_audio_disc_available",
        "udi",
        "audio_disc_removed",
        "disc_information_modified",
        "lookup_cddb_done",
        "KCDDB::Result",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'audioDiscDetected'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioDiscRemoved'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cddbLookupStarted'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cddbLookupDone'
        QtMocHelpers::SignalData<void(const bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'cddbDataModified'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cddbDataSubmited'
        QtMocHelpers::SignalData<void(const bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'hasSelection'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(const int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'lookupCDDB'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'submitCDDB'
        QtMocHelpers::SlotData<bool()>(14, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'eject'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'new_audio_disc_available'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'audio_disc_removed'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'disc_information_modified'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'lookup_cddb_done'
        QtMocHelpers::SlotData<void(KCDDB::Result)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CDDAModel, qt_meta_tag_ZN9CDDAModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CDDAModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractTableModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9CDDAModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9CDDAModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9CDDAModelE_t>.metaTypes,
    nullptr
} };

void CDDAModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CDDAModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->audioDiscDetected(); break;
        case 1: _t->audioDiscRemoved(); break;
        case 2: _t->cddbLookupStarted(); break;
        case 3: _t->cddbLookupDone((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->cddbDataModified(); break;
        case 5: _t->cddbDataSubmited((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->hasSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->lookupCDDB(); break;
        case 9: { bool _r = _t->submitCDDB();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->eject(); break;
        case 11: _t->new_audio_disc_available((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->audio_disc_removed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->disc_information_modified(); break;
        case 14: _t->lookup_cddb_done((*reinterpret_cast<std::add_pointer_t<KCDDB::Result>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CDDAModel::*)()>(_a, &CDDAModel::audioDiscDetected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAModel::*)()>(_a, &CDDAModel::audioDiscRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAModel::*)()>(_a, &CDDAModel::cddbLookupStarted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAModel::*)(const bool )>(_a, &CDDAModel::cddbLookupDone, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAModel::*)()>(_a, &CDDAModel::cddbDataModified, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAModel::*)(const bool )>(_a, &CDDAModel::cddbDataSubmited, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAModel::*)(bool )>(_a, &CDDAModel::hasSelection, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CDDAModel::*)(const int )>(_a, &CDDAModel::selectionChanged, 7))
            return;
    }
}

const QMetaObject *CDDAModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CDDAModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9CDDAModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractTableModel::qt_metacast(_clname);
}

int CDDAModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void CDDAModel::audioDiscDetected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CDDAModel::audioDiscRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CDDAModel::cddbLookupStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CDDAModel::cddbLookupDone(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CDDAModel::cddbDataModified()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CDDAModel::cddbDataSubmited(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void CDDAModel::hasSelection(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CDDAModel::selectionChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
