/********************************************************************************
** Form generated from reading UI file 'profiledatawidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEDATAWIDGETUI_H
#define UI_PROFILEDATAWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kiconbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ProfileDataWidgetUI
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    KIconButton *kiconbutton_icon;
    QLineEdit *qlineedit_name;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout;
    KComboBox *kcombobox_encoder;
    QStackedWidget *stackedWidget_encoder;
    QWidget *page_2;
    QWidget *tab_3;
    QGridLayout *gridLayout_5;
    QGroupBox *groupBox_filenames;
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label_scheme;
    QLineEdit *qlineedit_scheme;
    QPushButton *kpushbutton_scheme;
    QCheckBox *checkBox_fat32compatible;
    QCheckBox *checkBox_underscore;
    QCheckBox *checkBox_2digitstracknum;
    QSpacerItem *verticalSpacer;
    QWidget *tab_2;
    QGridLayout *gridLayout_4;
    QGroupBox *groupBox_extrafiles;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QCheckBox *checkBox_cover;
    QPushButton *kpushbutton_playlist;
    QCheckBox *checkBox_hashlist;
    QCheckBox *checkBox_cuesheet;
    QCheckBox *checkBox_playlist;
    QPushButton *kpushbutton_info;
    QPushButton *kpushbutton_cover;
    QPushButton *kpushbutton_cuesheet;
    QCheckBox *checkBox_info;
    QPushButton *kpushbutton_hashlist;
    QPushButton *kpushbutton_logfile;
    QCheckBox *checkBox_logfile;
    QGroupBox *groupBox_singlefile;
    QGridLayout *gridLayout_3;
    QCheckBox *checkBox_singlefile;
    QPushButton *kpushbutton_singlefile;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *ProfileDataWidgetUI)
    {
        if (ProfileDataWidgetUI->objectName().isEmpty())
            ProfileDataWidgetUI->setObjectName("ProfileDataWidgetUI");
        ProfileDataWidgetUI->resize(462, 442);
        verticalLayout_3 = new QVBoxLayout(ProfileDataWidgetUI);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kiconbutton_icon = new KIconButton(ProfileDataWidgetUI);
        kiconbutton_icon->setObjectName("kiconbutton_icon");

        horizontalLayout_2->addWidget(kiconbutton_icon);

        qlineedit_name = new QLineEdit(ProfileDataWidgetUI);
        qlineedit_name->setObjectName("qlineedit_name");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(qlineedit_name->sizePolicy().hasHeightForWidth());
        qlineedit_name->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(qlineedit_name);


        verticalLayout_3->addLayout(horizontalLayout_2);

        tabWidget = new QTabWidget(ProfileDataWidgetUI);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout = new QVBoxLayout(tab);
        verticalLayout->setObjectName("verticalLayout");
        kcombobox_encoder = new KComboBox(tab);
        kcombobox_encoder->setObjectName("kcombobox_encoder");
        QFont font;
        font.setBold(false);
        kcombobox_encoder->setFont(font);

        verticalLayout->addWidget(kcombobox_encoder);

        stackedWidget_encoder = new QStackedWidget(tab);
        stackedWidget_encoder->setObjectName("stackedWidget_encoder");
        stackedWidget_encoder->setMinimumSize(QSize(430, 300));
        stackedWidget_encoder->setFont(font);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        stackedWidget_encoder->addWidget(page_2);

        verticalLayout->addWidget(stackedWidget_encoder);

        tabWidget->addTab(tab, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_5 = new QGridLayout(tab_3);
        gridLayout_5->setObjectName("gridLayout_5");
        groupBox_filenames = new QGroupBox(tab_3);
        groupBox_filenames->setObjectName("groupBox_filenames");
        groupBox_filenames->setEnabled(true);
        groupBox_filenames->setTitle(QString::fromUtf8(""));
        gridLayout_2 = new QGridLayout(groupBox_filenames);
        gridLayout_2->setObjectName("gridLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_scheme = new QLabel(groupBox_filenames);
        label_scheme->setObjectName("label_scheme");
        label_scheme->setFont(font);

        horizontalLayout->addWidget(label_scheme);

        qlineedit_scheme = new QLineEdit(groupBox_filenames);
        qlineedit_scheme->setObjectName("qlineedit_scheme");
        qlineedit_scheme->setFont(font);

        horizontalLayout->addWidget(qlineedit_scheme);

        kpushbutton_scheme = new QPushButton(groupBox_filenames);
        kpushbutton_scheme->setObjectName("kpushbutton_scheme");
        kpushbutton_scheme->setFont(font);

        horizontalLayout->addWidget(kpushbutton_scheme);


        gridLayout_2->addLayout(horizontalLayout, 0, 0, 1, 1);

        checkBox_fat32compatible = new QCheckBox(groupBox_filenames);
        checkBox_fat32compatible->setObjectName("checkBox_fat32compatible");
        checkBox_fat32compatible->setFont(font);

        gridLayout_2->addWidget(checkBox_fat32compatible, 1, 0, 1, 1);

        checkBox_underscore = new QCheckBox(groupBox_filenames);
        checkBox_underscore->setObjectName("checkBox_underscore");
        checkBox_underscore->setFont(font);

        gridLayout_2->addWidget(checkBox_underscore, 2, 0, 1, 1);

        checkBox_2digitstracknum = new QCheckBox(groupBox_filenames);
        checkBox_2digitstracknum->setObjectName("checkBox_2digitstracknum");

        gridLayout_2->addWidget(checkBox_2digitstracknum, 3, 0, 1, 1);


        gridLayout_5->addWidget(groupBox_filenames, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 248, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer, 1, 0, 1, 1);

        tabWidget->addTab(tab_3, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_4 = new QGridLayout(tab_2);
        gridLayout_4->setObjectName("gridLayout_4");
        groupBox_extrafiles = new QGroupBox(tab_2);
        groupBox_extrafiles->setObjectName("groupBox_extrafiles");
        groupBox_extrafiles->setTitle(QString::fromUtf8(""));
        gridLayout = new QGridLayout(groupBox_extrafiles);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(81, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 2, 1, 1);

        checkBox_cover = new QCheckBox(groupBox_extrafiles);
        checkBox_cover->setObjectName("checkBox_cover");
        checkBox_cover->setFont(font);

        gridLayout->addWidget(checkBox_cover, 0, 0, 1, 1);

        kpushbutton_playlist = new QPushButton(groupBox_extrafiles);
        kpushbutton_playlist->setObjectName("kpushbutton_playlist");
        kpushbutton_playlist->setFont(font);

        gridLayout->addWidget(kpushbutton_playlist, 1, 1, 1, 1);

        checkBox_hashlist = new QCheckBox(groupBox_extrafiles);
        checkBox_hashlist->setObjectName("checkBox_hashlist");
        checkBox_hashlist->setFont(font);

        gridLayout->addWidget(checkBox_hashlist, 3, 0, 1, 1);

        checkBox_cuesheet = new QCheckBox(groupBox_extrafiles);
        checkBox_cuesheet->setObjectName("checkBox_cuesheet");

        gridLayout->addWidget(checkBox_cuesheet, 4, 0, 1, 1);

        checkBox_playlist = new QCheckBox(groupBox_extrafiles);
        checkBox_playlist->setObjectName("checkBox_playlist");
        checkBox_playlist->setFont(font);

        gridLayout->addWidget(checkBox_playlist, 1, 0, 1, 1);

        kpushbutton_info = new QPushButton(groupBox_extrafiles);
        kpushbutton_info->setObjectName("kpushbutton_info");
        kpushbutton_info->setFont(font);

        gridLayout->addWidget(kpushbutton_info, 2, 1, 1, 1);

        kpushbutton_cover = new QPushButton(groupBox_extrafiles);
        kpushbutton_cover->setObjectName("kpushbutton_cover");
        kpushbutton_cover->setFont(font);

        gridLayout->addWidget(kpushbutton_cover, 0, 1, 1, 1);

        kpushbutton_cuesheet = new QPushButton(groupBox_extrafiles);
        kpushbutton_cuesheet->setObjectName("kpushbutton_cuesheet");

        gridLayout->addWidget(kpushbutton_cuesheet, 4, 1, 1, 1);

        checkBox_info = new QCheckBox(groupBox_extrafiles);
        checkBox_info->setObjectName("checkBox_info");
        checkBox_info->setFont(font);

        gridLayout->addWidget(checkBox_info, 2, 0, 1, 1);

        kpushbutton_hashlist = new QPushButton(groupBox_extrafiles);
        kpushbutton_hashlist->setObjectName("kpushbutton_hashlist");
        kpushbutton_hashlist->setFont(font);

        gridLayout->addWidget(kpushbutton_hashlist, 3, 1, 1, 1);

        kpushbutton_logfile = new QPushButton(groupBox_extrafiles);
        kpushbutton_logfile->setObjectName("kpushbutton_logfile");

        gridLayout->addWidget(kpushbutton_logfile, 5, 1, 1, 1);

        checkBox_logfile = new QCheckBox(groupBox_extrafiles);
        checkBox_logfile->setObjectName("checkBox_logfile");

        gridLayout->addWidget(checkBox_logfile, 5, 0, 1, 1);


        gridLayout_4->addWidget(groupBox_extrafiles, 0, 0, 1, 1);

        groupBox_singlefile = new QGroupBox(tab_2);
        groupBox_singlefile->setObjectName("groupBox_singlefile");
        groupBox_singlefile->setTitle(QString::fromUtf8(""));
        gridLayout_3 = new QGridLayout(groupBox_singlefile);
        gridLayout_3->setObjectName("gridLayout_3");
        checkBox_singlefile = new QCheckBox(groupBox_singlefile);
        checkBox_singlefile->setObjectName("checkBox_singlefile");
        checkBox_singlefile->setEnabled(true);
        checkBox_singlefile->setMinimumSize(QSize(134, 0));

        gridLayout_3->addWidget(checkBox_singlefile, 0, 0, 1, 1);

        kpushbutton_singlefile = new QPushButton(groupBox_singlefile);
        kpushbutton_singlefile->setObjectName("kpushbutton_singlefile");
        kpushbutton_singlefile->setEnabled(true);

        gridLayout_3->addWidget(kpushbutton_singlefile, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(187, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 0, 2, 1, 1);


        gridLayout_4->addWidget(groupBox_singlefile, 1, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 88, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer_2, 2, 0, 1, 1);

        tabWidget->addTab(tab_2, QString());

        verticalLayout_3->addWidget(tabWidget);


        retranslateUi(ProfileDataWidgetUI);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ProfileDataWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *ProfileDataWidgetUI)
    {
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Encoder", nullptr));
        label_scheme->setText(tr2i18n("Scheme:", nullptr));
        qlineedit_scheme->setPlaceholderText(tr2i18n("Please set a scheme", nullptr));
        checkBox_fat32compatible->setText(tr2i18n("Create FAT32 compatible filenames", nullptr));
        checkBox_underscore->setText(tr2i18n("Replace spaces with underscores", nullptr));
#if QT_CONFIG(tooltip)
        checkBox_2digitstracknum->setToolTip(tr2i18n("This setting overrides any parameterized variable settings in the scheme", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBox_2digitstracknum->setText(tr2i18n("Set 2 digits track number (e.g. 01, 02, 03)\342\200\246", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Filenames", nullptr));
        checkBox_cover->setText(tr2i18n("Store cover file", nullptr));
        kpushbutton_playlist->setText(tr2i18n("Settings..", nullptr));
        checkBox_hashlist->setText(tr2i18n("Create hashlist", nullptr));
        checkBox_cuesheet->setText(tr2i18n("Create cue sheet", nullptr));
        checkBox_playlist->setText(tr2i18n("Create playlist", nullptr));
        kpushbutton_info->setText(tr2i18n("Settings..", nullptr));
        kpushbutton_cover->setText(tr2i18n("Settings..", nullptr));
        kpushbutton_cuesheet->setText(tr2i18n("Settings..", nullptr));
        checkBox_info->setText(tr2i18n("Create info file", nullptr));
        kpushbutton_hashlist->setText(tr2i18n("Settings..", nullptr));
        kpushbutton_logfile->setText(tr2i18n("Settings..", nullptr));
        checkBox_logfile->setText(tr2i18n("Save log file", nullptr));
        checkBox_singlefile->setText(tr2i18n("Write single file", nullptr));
        kpushbutton_singlefile->setText(tr2i18n("Settings..", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Extra", nullptr));
        (void)ProfileDataWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class ProfileDataWidgetUI: public Ui_ProfileDataWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEDATAWIDGETUI_H

