/* AUDEX CDDA EXTRACTOR
 * SPDX-FileCopyrightText: Copyright (C) 2007 Marco Nelles
 * <https://userbase.kde.org/Audex>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "devicewidget.h"

deviceWidget::deviceWidget(QWidget *parent)
    : deviceWidgetUI(parent)
{
    Q_UNUSED(parent);
}

deviceWidget::~deviceWidget()
{
}
