/********************************************************************************
** Form generated from reading UI file 'extractingprogresswidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXTRACTINGPROGRESSWIDGETUI_H
#define UI_EXTRACTINGPROGRESSWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_ExtractingProgressWidgetUI
{
public:
    QGridLayout *gridLayout_2;
    KSqueezedTextLabel *label_header;
    QToolButton *details_button;
    QWidget *details;
    QGridLayout *gridLayout;
    QListWidget *klistwidget;
    QHBoxLayout *horizontalLayout;
    QLabel *label_extracting;
    QLabel *label_speed_extracting;
    QProgressBar *progressBar_extracting;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_encoding;
    QLabel *label_speed_encoding;
    QProgressBar *progressBar_encoding;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_overall;
    KSqueezedTextLabel *label_overall_track;
    QProgressBar *progressBar_overall;

    void setupUi(QWidget *ExtractingProgressWidgetUI)
    {
        if (ExtractingProgressWidgetUI->objectName().isEmpty())
            ExtractingProgressWidgetUI->setObjectName("ExtractingProgressWidgetUI");
        ExtractingProgressWidgetUI->resize(512, 492);
        gridLayout_2 = new QGridLayout(ExtractingProgressWidgetUI);
        gridLayout_2->setObjectName("gridLayout_2");
        label_header = new KSqueezedTextLabel(ExtractingProgressWidgetUI);
        label_header->setObjectName("label_header");
        QFont font;
        font.setBold(true);
        label_header->setFont(font);
        label_header->setTextElideMode(Qt::TextElideMode::ElideRight);

        gridLayout_2->addWidget(label_header, 0, 0, 1, 1);

        details_button = new QToolButton(ExtractingProgressWidgetUI);
        details_button->setObjectName("details_button");
        details_button->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonIconOnly);
        details_button->setAutoRaise(true);
        details_button->setArrowType(Qt::ArrowType::UpArrow);

        gridLayout_2->addWidget(details_button, 0, 1, 1, 1);

        details = new QWidget(ExtractingProgressWidgetUI);
        details->setObjectName("details");
        gridLayout = new QGridLayout(details);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        klistwidget = new QListWidget(details);
        klistwidget->setObjectName("klistwidget");
        klistwidget->setMinimumSize(QSize(500, 0));

        gridLayout->addWidget(klistwidget, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_extracting = new QLabel(details);
        label_extracting->setObjectName("label_extracting");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_extracting->sizePolicy().hasHeightForWidth());
        label_extracting->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label_extracting);

        label_speed_extracting = new QLabel(details);
        label_speed_extracting->setObjectName("label_speed_extracting");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_speed_extracting->sizePolicy().hasHeightForWidth());
        label_speed_extracting->setSizePolicy(sizePolicy1);
        label_speed_extracting->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout->addWidget(label_speed_extracting);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 1);

        progressBar_extracting = new QProgressBar(details);
        progressBar_extracting->setObjectName("progressBar_extracting");
        progressBar_extracting->setEnabled(true);
        progressBar_extracting->setValue(0);
        progressBar_extracting->setOrientation(Qt::Orientation::Horizontal);

        gridLayout->addWidget(progressBar_extracting, 3, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_encoding = new QLabel(details);
        label_encoding->setObjectName("label_encoding");
        sizePolicy.setHeightForWidth(label_encoding->sizePolicy().hasHeightForWidth());
        label_encoding->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(label_encoding);

        label_speed_encoding = new QLabel(details);
        label_speed_encoding->setObjectName("label_speed_encoding");
        sizePolicy1.setHeightForWidth(label_speed_encoding->sizePolicy().hasHeightForWidth());
        label_speed_encoding->setSizePolicy(sizePolicy1);
        label_speed_encoding->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_2->addWidget(label_speed_encoding);


        gridLayout->addLayout(horizontalLayout_2, 5, 0, 1, 1);

        progressBar_encoding = new QProgressBar(details);
        progressBar_encoding->setObjectName("progressBar_encoding");
        progressBar_encoding->setValue(0);
        progressBar_encoding->setOrientation(Qt::Orientation::Horizontal);

        gridLayout->addWidget(progressBar_encoding, 7, 0, 1, 1);


        gridLayout_2->addWidget(details, 1, 0, 1, 2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_overall = new QLabel(ExtractingProgressWidgetUI);
        label_overall->setObjectName("label_overall");
        sizePolicy.setHeightForWidth(label_overall->sizePolicy().hasHeightForWidth());
        label_overall->setSizePolicy(sizePolicy);

        horizontalLayout_3->addWidget(label_overall);

        label_overall_track = new KSqueezedTextLabel(ExtractingProgressWidgetUI);
        label_overall_track->setObjectName("label_overall_track");
        sizePolicy1.setHeightForWidth(label_overall_track->sizePolicy().hasHeightForWidth());
        label_overall_track->setSizePolicy(sizePolicy1);
        QFont font1;
        font1.setItalic(false);
        label_overall_track->setFont(font1);
        label_overall_track->setTextElideMode(Qt::TextElideMode::ElideLeft);

        horizontalLayout_3->addWidget(label_overall_track);


        gridLayout_2->addLayout(horizontalLayout_3, 2, 0, 1, 2);

        progressBar_overall = new QProgressBar(ExtractingProgressWidgetUI);
        progressBar_overall->setObjectName("progressBar_overall");
        progressBar_overall->setValue(0);
        progressBar_overall->setOrientation(Qt::Orientation::Horizontal);

        gridLayout_2->addWidget(progressBar_overall, 3, 0, 1, 2);


        retranslateUi(ExtractingProgressWidgetUI);

        QMetaObject::connectSlotsByName(ExtractingProgressWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *ExtractingProgressWidgetUI)
    {
#if QT_CONFIG(tooltip)
        details_button->setToolTip(tr2i18n("Show/hide details", nullptr));
#endif // QT_CONFIG(tooltip)
        details_button->setText(tr2i18n("...", nullptr));
        label_extracting->setText(tr2i18n("Ripping Track 8 of 12", nullptr));
        label_speed_extracting->setText(tr2i18n("<html><head/><body><p><span style=\" font-style:italic;\">Speed: 0\303\227</span></p></body></html>", nullptr));
        progressBar_extracting->setFormat(tr2i18n("%p%", nullptr));
        label_encoding->setText(tr2i18n("Encoding Track 8 of 12", nullptr));
        label_speed_encoding->setText(tr2i18n("<html><head/><body><p><span style=\" font-style:italic;\">Speed: 0\303\227</span></p></body></html>", nullptr));
        progressBar_encoding->setFormat(tr2i18n("%p%", nullptr));
        label_overall->setText(tr2i18n("Overall progress", nullptr));
        label_overall_track->setText(tr2i18n("KSqueezedTextLabel", nullptr));
        progressBar_overall->setFormat(tr2i18n("%p%", nullptr));
        (void)ExtractingProgressWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class ExtractingProgressWidgetUI: public Ui_ExtractingProgressWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXTRACTINGPROGRESSWIDGETUI_H

