/********************************************************************************
** Form generated from reading UI file 'lamewidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LAMEWIDGETUI_H
#define UI_LAMEWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LAMEWidgetUI
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QRadioButton *radioButton_medium;
    QRadioButton *radioButton_extreme;
    QSpacerItem *horizontalSpacer_2;
    QRadioButton *radioButton_standard;
    QRadioButton *radioButton_insane;
    QRadioButton *radioButton_custom;
    QCheckBox *checkBox_cbr;
    QLabel *label_targetbitrate;
    QHBoxLayout *horizontalLayout_3;
    QVBoxLayout *verticalLayout;
    QSlider *horizontalSlider_bitrate;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_lowest;
    QLabel *label_highest;
    QVBoxLayout *verticalLayout_2;
    QSpinBox *kintspinbox_bitrate;
    QSpacerItem *verticalSpacer_2;
    QCheckBox *checkBox_embedcover;
    QHBoxLayout *horizontalLayout;
    QLabel *label_suffix;
    QLineEdit *qlineedit_suffix;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *LAMEWidgetUI)
    {
        if (LAMEWidgetUI->objectName().isEmpty())
            LAMEWidgetUI->setObjectName("LAMEWidgetUI");
        LAMEWidgetUI->resize(430, 300);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(LAMEWidgetUI->sizePolicy().hasHeightForWidth());
        LAMEWidgetUI->setSizePolicy(sizePolicy);
        LAMEWidgetUI->setMinimumSize(QSize(430, 300));
        gridLayout_2 = new QGridLayout(LAMEWidgetUI);
        gridLayout_2->setObjectName("gridLayout_2");
        groupBox = new QGroupBox(LAMEWidgetUI);
        groupBox->setObjectName("groupBox");
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        QFont font;
        font.setBold(true);
        groupBox->setFont(font);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        radioButton_medium = new QRadioButton(groupBox);
        radioButton_medium->setObjectName("radioButton_medium");
        QFont font1;
        font1.setBold(false);
        radioButton_medium->setFont(font1);

        gridLayout->addWidget(radioButton_medium, 0, 0, 1, 1);

        radioButton_extreme = new QRadioButton(groupBox);
        radioButton_extreme->setObjectName("radioButton_extreme");
        radioButton_extreme->setFont(font1);

        gridLayout->addWidget(radioButton_extreme, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(21, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 2, 2, 1);

        radioButton_standard = new QRadioButton(groupBox);
        radioButton_standard->setObjectName("radioButton_standard");
        radioButton_standard->setFont(font1);

        gridLayout->addWidget(radioButton_standard, 1, 0, 1, 1);

        radioButton_insane = new QRadioButton(groupBox);
        radioButton_insane->setObjectName("radioButton_insane");
        radioButton_insane->setFont(font1);

        gridLayout->addWidget(radioButton_insane, 1, 1, 1, 1);

        radioButton_custom = new QRadioButton(groupBox);
        radioButton_custom->setObjectName("radioButton_custom");
        radioButton_custom->setFont(font1);

        gridLayout->addWidget(radioButton_custom, 2, 0, 1, 1);


        gridLayout_2->addWidget(groupBox, 0, 0, 1, 1);

        checkBox_cbr = new QCheckBox(LAMEWidgetUI);
        checkBox_cbr->setObjectName("checkBox_cbr");

        gridLayout_2->addWidget(checkBox_cbr, 1, 0, 1, 1);

        label_targetbitrate = new QLabel(LAMEWidgetUI);
        label_targetbitrate->setObjectName("label_targetbitrate");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_targetbitrate->sizePolicy().hasHeightForWidth());
        label_targetbitrate->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(label_targetbitrate, 2, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        horizontalSlider_bitrate = new QSlider(LAMEWidgetUI);
        horizontalSlider_bitrate->setObjectName("horizontalSlider_bitrate");
        horizontalSlider_bitrate->setMinimum(80);
        horizontalSlider_bitrate->setMaximum(320);
        horizontalSlider_bitrate->setPageStep(10);
        horizontalSlider_bitrate->setOrientation(Qt::Horizontal);
        horizontalSlider_bitrate->setTickPosition(QSlider::TicksBelow);

        verticalLayout->addWidget(horizontalSlider_bitrate);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_lowest = new QLabel(LAMEWidgetUI);
        label_lowest->setObjectName("label_lowest");
        QFont font2;
        font2.setItalic(true);
        label_lowest->setFont(font2);

        horizontalLayout_2->addWidget(label_lowest);

        label_highest = new QLabel(LAMEWidgetUI);
        label_highest->setObjectName("label_highest");
        label_highest->setFont(font2);
        label_highest->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(label_highest);


        verticalLayout->addLayout(horizontalLayout_2);


        horizontalLayout_3->addLayout(verticalLayout);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        kintspinbox_bitrate = new QSpinBox(LAMEWidgetUI);
        kintspinbox_bitrate->setObjectName("kintspinbox_bitrate");
        kintspinbox_bitrate->setMaximum(99);
        kintspinbox_bitrate->setValue(0);

        verticalLayout_2->addWidget(kintspinbox_bitrate);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_2);


        horizontalLayout_3->addLayout(verticalLayout_2);


        gridLayout_2->addLayout(horizontalLayout_3, 3, 0, 1, 1);

        checkBox_embedcover = new QCheckBox(LAMEWidgetUI);
        checkBox_embedcover->setObjectName("checkBox_embedcover");

        gridLayout_2->addWidget(checkBox_embedcover, 4, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_suffix = new QLabel(LAMEWidgetUI);
        label_suffix->setObjectName("label_suffix");
        sizePolicy1.setHeightForWidth(label_suffix->sizePolicy().hasHeightForWidth());
        label_suffix->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(label_suffix);

        qlineedit_suffix = new QLineEdit(LAMEWidgetUI);
        qlineedit_suffix->setObjectName("qlineedit_suffix");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(30);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(qlineedit_suffix->sizePolicy().hasHeightForWidth());
        qlineedit_suffix->setSizePolicy(sizePolicy2);
        qlineedit_suffix->setMaximumSize(QSize(70, 16777215));

        horizontalLayout->addWidget(qlineedit_suffix);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout_2->addLayout(horizontalLayout, 5, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 6, 0, 1, 1);


        retranslateUi(LAMEWidgetUI);

        QMetaObject::connectSlotsByName(LAMEWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *LAMEWidgetUI)
    {
        groupBox->setTitle(tr2i18n("Quality/Bitrate", nullptr));
#if QT_CONFIG(tooltip)
        radioButton_medium->setToolTip(tr2i18n("This preset should provide perceptual transparency to most people.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButton_medium->setText(tr2i18n("Medium (140...185 kbit/s)", nullptr));
#if QT_CONFIG(tooltip)
        radioButton_extreme->setToolTip(tr2i18n("If you have extremely good hearing and similar equipment, this preset will generally provide slightly higher quality than the \"standard\" mode", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButton_extreme->setText(tr2i18n("Extreme (220...260 kbits/s)", nullptr));
#if QT_CONFIG(tooltip)
        radioButton_standard->setToolTip(tr2i18n("This preset should generally be transparent to most people.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButton_standard->setText(tr2i18n("Standard (170...210 kbit/s)", nullptr));
#if QT_CONFIG(tooltip)
        radioButton_insane->setToolTip(tr2i18n("This preset will usually be overkill, but if you want to have the absolute highest quality with no regard to filesize, this is the way to go.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButton_insane->setText(tr2i18n("Insane (320 kbit/s)", nullptr));
        radioButton_custom->setText(tr2i18n("Custom", nullptr));
        checkBox_cbr->setText(tr2i18n("Constant Bitrate", nullptr));
        label_targetbitrate->setText(tr2i18n("Target bitrate (kbit/s)", nullptr));
        label_lowest->setText(tr2i18n("Lowest", nullptr));
        label_highest->setText(tr2i18n("Highest", nullptr));
        kintspinbox_bitrate->setSuffix(tr2i18n(" kbit/s", nullptr));
        checkBox_embedcover->setText(tr2i18n("Embed cover in music file", nullptr));
        label_suffix->setText(tr2i18n("Suffix:", nullptr));
        (void)LAMEWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class LAMEWidgetUI: public Ui_LAMEWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LAMEWIDGETUI_H

