/********************************************************************************
** Form generated from reading UI file 'oggencwidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OGGENCWIDGETUI_H
#define UI_OGGENCWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OggEncWidgetUI
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QSlider *horizontalSlider_quality;
    QDoubleSpinBox *kdoublenuminput_quality;
    QLabel *label_lowest;
    QLabel *label_highest;
    QLabel *label_targetbitrate;
    QLineEdit *lineEdit_kbps;
    QLabel *label_kbits;
    QCheckBox *checkBox_minbitrate;
    QSpinBox *kintspinbox_minbitrate;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *checkBox_maxbitrate;
    QSpinBox *kintspinbox_maxbitrate;
    QLabel *label_maxbitrate_kbps;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout;
    QLabel *label_suffix;
    QLineEdit *qlineedit_suffix;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;
    QLabel *label_minbitrate_kbps;

    void setupUi(QWidget *OggEncWidgetUI)
    {
        if (OggEncWidgetUI->objectName().isEmpty())
            OggEncWidgetUI->setObjectName("OggEncWidgetUI");
        OggEncWidgetUI->resize(430, 300);
        OggEncWidgetUI->setMinimumSize(QSize(430, 300));
        gridLayout_2 = new QGridLayout(OggEncWidgetUI);
        gridLayout_2->setObjectName("gridLayout_2");
        groupBox = new QGroupBox(OggEncWidgetUI);
        groupBox->setObjectName("groupBox");
        QFont font;
        font.setBold(true);
        groupBox->setFont(font);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        horizontalSlider_quality = new QSlider(groupBox);
        horizontalSlider_quality->setObjectName("horizontalSlider_quality");
        horizontalSlider_quality->setMinimum(-10);
        horizontalSlider_quality->setMaximum(100);
        horizontalSlider_quality->setPageStep(10);
        horizontalSlider_quality->setOrientation(Qt::Horizontal);
        horizontalSlider_quality->setTickPosition(QSlider::TicksBelow);

        gridLayout->addWidget(horizontalSlider_quality, 0, 0, 1, 4);

        kdoublenuminput_quality = new QDoubleSpinBox(groupBox);
        kdoublenuminput_quality->setObjectName("kdoublenuminput_quality");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kdoublenuminput_quality->sizePolicy().hasHeightForWidth());
        kdoublenuminput_quality->setSizePolicy(sizePolicy);
        kdoublenuminput_quality->setMaximumSize(QSize(60, 16777215));
        kdoublenuminput_quality->setBaseSize(QSize(0, 0));
        QFont font1;
        font1.setBold(false);
        kdoublenuminput_quality->setFont(font1);
        kdoublenuminput_quality->setDecimals(1);
        kdoublenuminput_quality->setMinimum(-1.000000000000000);
        kdoublenuminput_quality->setMaximum(10.000000000000000);
        kdoublenuminput_quality->setSingleStep(1.000000000000000);

        gridLayout->addWidget(kdoublenuminput_quality, 0, 4, 1, 1);

        label_lowest = new QLabel(groupBox);
        label_lowest->setObjectName("label_lowest");
        QFont font2;
        font2.setBold(false);
        font2.setItalic(true);
        label_lowest->setFont(font2);

        gridLayout->addWidget(label_lowest, 1, 0, 1, 1);

        label_highest = new QLabel(groupBox);
        label_highest->setObjectName("label_highest");
        label_highest->setFont(font2);
        label_highest->setMouseTracking(true);
        label_highest->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_highest, 1, 3, 1, 1);

        label_targetbitrate = new QLabel(groupBox);
        label_targetbitrate->setObjectName("label_targetbitrate");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_targetbitrate->sizePolicy().hasHeightForWidth());
        label_targetbitrate->setSizePolicy(sizePolicy1);
        label_targetbitrate->setMinimumSize(QSize(101, 0));
        label_targetbitrate->setMaximumSize(QSize(101, 16777215));
        label_targetbitrate->setFont(font1);

        gridLayout->addWidget(label_targetbitrate, 2, 0, 1, 1);

        lineEdit_kbps = new QLineEdit(groupBox);
        lineEdit_kbps->setObjectName("lineEdit_kbps");
        lineEdit_kbps->setEnabled(true);
        sizePolicy.setHeightForWidth(lineEdit_kbps->sizePolicy().hasHeightForWidth());
        lineEdit_kbps->setSizePolicy(sizePolicy);
        lineEdit_kbps->setMinimumSize(QSize(51, 0));
        lineEdit_kbps->setMaximumSize(QSize(51, 16777215));
        lineEdit_kbps->setFont(font1);
        lineEdit_kbps->setReadOnly(true);

        gridLayout->addWidget(lineEdit_kbps, 2, 1, 1, 1);

        label_kbits = new QLabel(groupBox);
        label_kbits->setObjectName("label_kbits");
        label_kbits->setFont(font1);

        gridLayout->addWidget(label_kbits, 2, 2, 1, 1);


        gridLayout_2->addWidget(groupBox, 0, 0, 1, 4);

        checkBox_minbitrate = new QCheckBox(OggEncWidgetUI);
        checkBox_minbitrate->setObjectName("checkBox_minbitrate");
        checkBox_minbitrate->setChecked(false);

        gridLayout_2->addWidget(checkBox_minbitrate, 1, 0, 1, 1);

        kintspinbox_minbitrate = new QSpinBox(OggEncWidgetUI);
        kintspinbox_minbitrate->setObjectName("kintspinbox_minbitrate");
        kintspinbox_minbitrate->setMaximumSize(QSize(75, 16777215));
        kintspinbox_minbitrate->setMaximum(200);

        gridLayout_2->addWidget(kintspinbox_minbitrate, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(4, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 1, 3, 1, 1);

        checkBox_maxbitrate = new QCheckBox(OggEncWidgetUI);
        checkBox_maxbitrate->setObjectName("checkBox_maxbitrate");

        gridLayout_2->addWidget(checkBox_maxbitrate, 2, 0, 1, 1);

        kintspinbox_maxbitrate = new QSpinBox(OggEncWidgetUI);
        kintspinbox_maxbitrate->setObjectName("kintspinbox_maxbitrate");
        kintspinbox_maxbitrate->setMaximumSize(QSize(75, 16777215));
        kintspinbox_maxbitrate->setMaximum(1000);
        kintspinbox_maxbitrate->setValue(200);

        gridLayout_2->addWidget(kintspinbox_maxbitrate, 2, 1, 1, 1);

        label_maxbitrate_kbps = new QLabel(OggEncWidgetUI);
        label_maxbitrate_kbps->setObjectName("label_maxbitrate_kbps");

        gridLayout_2->addWidget(label_maxbitrate_kbps, 2, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(4, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_3, 2, 3, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_suffix = new QLabel(OggEncWidgetUI);
        label_suffix->setObjectName("label_suffix");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_suffix->sizePolicy().hasHeightForWidth());
        label_suffix->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(label_suffix);

        qlineedit_suffix = new QLineEdit(OggEncWidgetUI);
        qlineedit_suffix->setObjectName("qlineedit_suffix");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(30);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(qlineedit_suffix->sizePolicy().hasHeightForWidth());
        qlineedit_suffix->setSizePolicy(sizePolicy3);
        qlineedit_suffix->setMaximumSize(QSize(70, 16777215));

        horizontalLayout->addWidget(qlineedit_suffix);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout_2->addLayout(horizontalLayout, 3, 0, 1, 4);

        verticalSpacer = new QSpacerItem(20, 108, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 4, 0, 1, 1);

        label_minbitrate_kbps = new QLabel(OggEncWidgetUI);
        label_minbitrate_kbps->setObjectName("label_minbitrate_kbps");

        gridLayout_2->addWidget(label_minbitrate_kbps, 1, 2, 1, 1);


        retranslateUi(OggEncWidgetUI);

        QMetaObject::connectSlotsByName(OggEncWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *OggEncWidgetUI)
    {
        groupBox->setTitle(tr2i18n("Quality", nullptr));
        label_lowest->setText(tr2i18n("Lowest", nullptr));
        label_highest->setText(tr2i18n("Highest", nullptr));
        label_targetbitrate->setText(tr2i18n("Target bitrate ~", nullptr));
        label_kbits->setText(tr2i18n("kbit/s", nullptr));
        checkBox_minbitrate->setText(tr2i18n("Set minimum bitrate", nullptr));
        checkBox_maxbitrate->setText(tr2i18n("Set maximum bitrate", nullptr));
        label_maxbitrate_kbps->setText(tr2i18n("kbit/s", nullptr));
        label_suffix->setText(tr2i18n("Suffix:", nullptr));
        label_minbitrate_kbps->setText(tr2i18n("kbit/s", nullptr));
        (void)OggEncWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class OggEncWidgetUI: public Ui_OggEncWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OGGENCWIDGETUI_H

