/********************************************************************************
** Form generated from reading UI file 'generalsettingswidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALSETTINGSWIDGETUI_H
#define UI_GENERALSETTINGSWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_GeneralSettingsWidgetUI
{
public:
    QGridLayout *gridLayout_4;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_3;
    QVBoxLayout *vboxLayout;
    QLabel *label_basePath;
    KUrlRequester *urlreq_basePath;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout_2;
    QCheckBox *kcfg_overwriteExistingFiles;
    QCheckBox *kcfg_deletePartialFiles;
    QCheckBox *kcfg_ejectCDTray;
    QCheckBox *kcfg_cddbLookupAuto;
    QCheckBox *kcfg_coverLookupAuto;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QSpinBox *kcfg_fetchCount;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GeneralSettingsWidgetUI)
    {
        if (GeneralSettingsWidgetUI->objectName().isEmpty())
            GeneralSettingsWidgetUI->setObjectName("GeneralSettingsWidgetUI");
        GeneralSettingsWidgetUI->resize(283, 394);
        gridLayout_4 = new QGridLayout(GeneralSettingsWidgetUI);
        gridLayout_4->setObjectName("gridLayout_4");
        groupBox_3 = new QGroupBox(GeneralSettingsWidgetUI);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_3 = new QGridLayout(groupBox_3);
        gridLayout_3->setObjectName("gridLayout_3");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        label_basePath = new QLabel(groupBox_3);
        label_basePath->setObjectName("label_basePath");

        vboxLayout->addWidget(label_basePath);

        urlreq_basePath = new KUrlRequester(groupBox_3);
        urlreq_basePath->setObjectName("urlreq_basePath");

        vboxLayout->addWidget(urlreq_basePath);


        gridLayout_3->addLayout(vboxLayout, 0, 0, 1, 1);


        gridLayout_4->addWidget(groupBox_3, 1, 0, 1, 1);

        groupBox_4 = new QGroupBox(GeneralSettingsWidgetUI);
        groupBox_4->setObjectName("groupBox_4");
        groupBox_4->setTitle(QString::fromUtf8(""));
        gridLayout_2 = new QGridLayout(groupBox_4);
        gridLayout_2->setObjectName("gridLayout_2");
        kcfg_overwriteExistingFiles = new QCheckBox(groupBox_4);
        kcfg_overwriteExistingFiles->setObjectName("kcfg_overwriteExistingFiles");

        gridLayout_2->addWidget(kcfg_overwriteExistingFiles, 0, 0, 1, 1);

        kcfg_deletePartialFiles = new QCheckBox(groupBox_4);
        kcfg_deletePartialFiles->setObjectName("kcfg_deletePartialFiles");

        gridLayout_2->addWidget(kcfg_deletePartialFiles, 1, 0, 1, 1);

        kcfg_ejectCDTray = new QCheckBox(groupBox_4);
        kcfg_ejectCDTray->setObjectName("kcfg_ejectCDTray");

        gridLayout_2->addWidget(kcfg_ejectCDTray, 2, 0, 1, 1);

        kcfg_cddbLookupAuto = new QCheckBox(groupBox_4);
        kcfg_cddbLookupAuto->setObjectName("kcfg_cddbLookupAuto");

        gridLayout_2->addWidget(kcfg_cddbLookupAuto, 3, 0, 1, 1);

        kcfg_coverLookupAuto = new QCheckBox(groupBox_4);
        kcfg_coverLookupAuto->setObjectName("kcfg_coverLookupAuto");
        kcfg_coverLookupAuto->setEnabled(false);

        gridLayout_2->addWidget(kcfg_coverLookupAuto, 4, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label = new QLabel(groupBox_4);
        label->setObjectName("label");
        label->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(label);

        kcfg_fetchCount = new QSpinBox(groupBox_4);
        kcfg_fetchCount->setObjectName("kcfg_fetchCount");
        kcfg_fetchCount->setEnabled(false);

        horizontalLayout_2->addWidget(kcfg_fetchCount);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        gridLayout_2->addLayout(horizontalLayout_2, 5, 0, 1, 1);


        gridLayout_4->addWidget(groupBox_4, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 33, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 2, 0, 1, 1);


        retranslateUi(GeneralSettingsWidgetUI);

        QMetaObject::connectSlotsByName(GeneralSettingsWidgetUI);
    } // setupUi

    void retranslateUi(QWidget *GeneralSettingsWidgetUI)
    {
        groupBox_3->setTitle(tr2i18n("Paths", nullptr));
        label_basePath->setText(tr2i18n("Base path to store music files:", nullptr));
        kcfg_overwriteExistingFiles->setText(tr2i18n("Overwrite existing files", nullptr));
        kcfg_deletePartialFiles->setText(tr2i18n("Delete partial files after cancel", nullptr));
        kcfg_ejectCDTray->setText(tr2i18n("Eject CD tray after finished extraction", nullptr));
        kcfg_cddbLookupAuto->setText(tr2i18n("Perform CDDB lookup automatically", nullptr));
        kcfg_coverLookupAuto->setText(tr2i18n("Perform cover lookup automatically", nullptr));
        label->setText(tr2i18n("Number of covers to fetch:", nullptr));
        (void)GeneralSettingsWidgetUI;
    } // retranslateUi

};

namespace Ui {
    class GeneralSettingsWidgetUI: public Ui_GeneralSettingsWidgetUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALSETTINGSWIDGETUI_H

